@@ -100,7 +100,7 @@ class BGGDualModule(CombinatorialFreeModule):
 
     - [Humphreys08]_
     """
-    def __init__(self, module):
+    def __init__(self, module) -> None:
         r"""
         Initialize ``self``.
 
@@ -458,7 +458,7 @@ class SimpleModuleIndices(IndexedFreeAbelianMonoid):
         """
         return super(IndexedMonoid, cls).__classcall__(cls, simple, prefix=prefix, **kwds)
 
-    def __init__(self, simple, prefix, category=None, **kwds):
+    def __init__(self, simple, prefix, category=None, **kwds) -> None:
         r"""
         Initialize ``self``.
 
@@ -591,7 +591,7 @@ class SimpleModuleIndices(IndexedFreeAbelianMonoid):
             self._construct_next_level()
         return self._weight_space_bases.get(mu, [])
 
-    def __contains__(self, m):
+    def __contains__(self, m) -> bool:
         r"""
         Check if ``m`` is contained in ``self``.
 
@@ -746,10 +746,10 @@ class SimpleModuleIndices(IndexedFreeAbelianMonoid):
                 mat = matrix(R, [[b[s] for s in supp] for b in wt_basis])
                 mat.echelonize()
                 for i, k in enumerate(self._weight_space_bases[mu]):
-                    data = {supp[ind]: R(c) for ind, c in mat[i].iteritems() if c}
+                    data = {supp[ind]: R(c) for ind, c in mat[i].items() if c}
                     self._basis[k] = ambient.element_class(ambient, data)
                 i = mat.nrows() - 1
-                data = {supp[ind]: R(c) for ind, c in mat[i].iteritems() if c}
+                data = {supp[ind]: R(c) for ind, c in mat[i].items() if c}
                 if data:
                     next_level[key] = ambient.element_class(ambient, data)
                     self._basis[key] = next_level[key]
@@ -815,7 +815,7 @@ class SimpleModule(ModulePrinting, CombinatorialFreeModule):
             return FiniteDimensionalSimpleModule(g, weight, *args, **kwds)
         return super().__classcall__(cls, g, weight, *args, **kwds)
 
-    def __init__(self, g, weight, prefix='f', basis_key=None, **kwds):
+    def __init__(self, g, weight, prefix='f', basis_key=None, **kwds) -> None:
         r"""
         Initialize ``self``.
 
