@@ -275,11 +275,11 @@ class YokonumaHeckeAlgebraGL(YokonumaHeckeAlgebra):
         self._n = n
         W = Permutations(n)
         import itertools
-        C = itertools.product(*([range(d)]*n))
+        C = itertools.product(*([range(d)] * n))
         indices = list(itertools.product(C, W))
         YokonumaHeckeAlgebra.__init__(self, d, W, q, R, indices)
 
-    def _repr_(self):
+    def _repr_(self) -> str:
         """
         Return a string representation of ``self``.
 
@@ -292,7 +292,7 @@ class YokonumaHeckeAlgebraGL(YokonumaHeckeAlgebra):
         return "Yokonuma-Hecke algebra of rank {} and order {} with q={} over {}".format(
             self._d, self._n, self._q, self.base_ring())
 
-    def _latex_(self):
+    def _latex_(self) -> str:
         r"""
         Return a latex representation of ``self``.
 
@@ -304,7 +304,7 @@ class YokonumaHeckeAlgebraGL(YokonumaHeckeAlgebra):
         """
         return "\\mathcal{Y}_{%s,%s}(%s)" % (self._d, self._n, self._q)
 
-    def _repr_term(self, m):
+    def _repr_term(self, m) -> str:
         """
         Return a string representation of the basis element indexed by ``m``.
 
@@ -316,7 +316,8 @@ class YokonumaHeckeAlgebraGL(YokonumaHeckeAlgebra):
         """
         def gen_str(e):
             return '' if e == 1 else '^%s' % e
-        lhs = '*'.join('t%s' % (j+1) + gen_str(i) for j,i in enumerate(m[0]) if i > 0)
+        lhs = '*'.join('t%s' % (j + 1) + gen_str(i)
+                       for j, i in enumerate(m[0]) if i > 0)
         redword = m[1].reduced_word()
         if not redword:
             if not lhs:
@@ -327,7 +328,7 @@ class YokonumaHeckeAlgebraGL(YokonumaHeckeAlgebra):
             return rhs
         return lhs + '*' + rhs
 
-    def _latex_term(self, m):
+    def _latex_term(self, m) -> str:
         r"""
         Return a latex representation for the basis element indexed by ``m``.
 
@@ -339,7 +340,8 @@ class YokonumaHeckeAlgebraGL(YokonumaHeckeAlgebra):
         """
         def gen_str(e):
             return '' if e == 1 else '^{%s}' % e
-        lhs = ' '.join('t_{%s}' % (j+1) + gen_str(i) for j,i in enumerate(m[0]) if i > 0)
+        lhs = ' '.join('t_{%s}' % (j + 1) + gen_str(i)
+                       for j, i in enumerate(m[0]) if i > 0)
         redword = m[1].reduced_word()
         if not redword:
             if not lhs:
@@ -688,7 +690,7 @@ class YokonumaHeckeAlgebraWeyl(YokonumaHeckeAlgebra):
         indices = cartesian_product([self._Q, W])
         YokonumaHeckeAlgebra.__init__(self, d, W, q, R, indices)
 
-    def _repr_(self):
+    def _repr_(self) -> str:
         """
         Return a string representation of ``self``.
 
@@ -701,7 +703,7 @@ class YokonumaHeckeAlgebraWeyl(YokonumaHeckeAlgebra):
         return "Yokonuma-Hecke algebra of rank {} for {} with q={} over {}".format(
             self._d, self._cartan_type, self._q, self.base_ring())
 
-    def _latex_(self):
+    def _latex_(self) -> str:
         r"""
         Return a latex representation of ``self``.
 
@@ -714,7 +716,7 @@ class YokonumaHeckeAlgebraWeyl(YokonumaHeckeAlgebra):
         from sage.misc.latex import latex
         return "\\mathcal{Y}_{%s,%s}(%s)" % (self._d, latex(self._cartan_type), self._q)
 
-    def _repr_term(self, m):
+    def _repr_term(self, m) -> str:
         """
         Return a string representation of the basis element indexed by ``m``.
 
@@ -740,7 +742,7 @@ class YokonumaHeckeAlgebraWeyl(YokonumaHeckeAlgebra):
             return rhs
         return lhs + '*' + rhs
 
-    def _latex_term(self, m):
+    def _latex_term(self, m) -> str:
         r"""
         Return a latex representation for the basis element indexed by ``m``.
 
