@@ -1,4 +1,3 @@
-# sage_setup: distribution = sagemath-categories
 """
 Examples of finite monoids
 """
@@ -21,7 +20,7 @@ from sage.rings.integer_ring import ZZ
 
 class IntegerModMonoid(UniqueRepresentation, Parent):
     r"""
-    An example of a finite monoid: the integers mod `n`
+    An example of a finite monoid: the integers mod `n`.
 
     This class illustrates a minimal implementation of a finite monoid.
 
@@ -62,6 +61,8 @@ class IntegerModMonoid(UniqueRepresentation, Parent):
         running ._test_one() . . . pass
         running ._test_pickling() . . . pass
         running ._test_prod() . . . pass
+        running ._test_random() . . . pass
+        running ._test_rank() . . . pass
         running ._test_some_elements() . . . pass
     """
 
@@ -115,7 +116,6 @@ class IntegerModMonoid(UniqueRepresentation, Parent):
             sage: M = FiniteMonoids().example()
             sage: M.one()
             1
-
         """
         return self(ZZ.one())
 
@@ -134,7 +134,7 @@ class IntegerModMonoid(UniqueRepresentation, Parent):
 
     def an_element(self):
         r"""
-        Returns an element of the monoid, as per :meth:`Sets.ParentMethods.an_element`.
+        Return an element of the monoid, as per :meth:`Sets.ParentMethods.an_element`.
 
         EXAMPLES::
 
