@@ -1,4 +1,3 @@
-# sage_setup: distribution = sagemath-categories
 # sage.doctest: needs sage.groups
 r"""
 Groupoid
@@ -40,7 +39,7 @@ class Groupoid(CategoryWithParameters):
             sage: C = Groupoid(S8)
             sage: TestSuite(C).run()
         """
-        CategoryWithParameters.__init__(self) #, "Groupoid")
+        CategoryWithParameters.__init__(self)  # "Groupoid")
         if G is None:
             from sage.groups.perm_gps.permgroup_named import SymmetricGroup
             G = SymmetricGroup(8)
@@ -56,8 +55,8 @@ class Groupoid(CategoryWithParameters):
         """
         return "Groupoid with underlying set %s" % self.__G
 
-    #def construction(self):
-    #    return (self.__class__, self.__G)
+    # def construction(self):
+    #     return (self.__class__, self.__G)
 
     def _make_named_class_key(self, name):
         """
