@@ -207,7 +207,7 @@ class GabidulinCode(AbstractLinearRankMetricCode):
             if not len(evaluation_points) == length:
                 raise ValueError("the number of evaluation points should be equal to the length of the code")
             for i in range(length):
-                if not evaluation_points[i] in base_field:
+                if evaluation_points[i] not in base_field:
                     raise ValueError("evaluation point does not belong to the 'base field'")
             basis = self.matrix_form_of_vector(vector(evaluation_points))
             if basis.rank() != length:
@@ -257,9 +257,7 @@ class GabidulinCode(AbstractLinearRankMetricCode):
 
         - ``other`` -- another Gabidulin Code object
 
-        OUTPUT:
-
-        - ``True`` or ``False``
+        OUTPUT: boolean
 
         EXAMPLES::
 
@@ -399,7 +397,7 @@ class GabidulinVectorEvaluationEncoder(Encoder):
 
         INPUT:
 
-        - ``code`` -- the associated code of this encoder.
+        - ``code`` -- the associated code of this encoder
 
         EXAMPLES::
 
@@ -467,9 +465,7 @@ class GabidulinVectorEvaluationEncoder(Encoder):
 
         - ``other`` -- another Gabidulin Generator Matrix Encoder
 
-        OUTPUT:
-
-        - ``True`` or ``False``
+        OUTPUT: boolean
 
         EXAMPLES::
 
@@ -625,9 +621,7 @@ class GabidulinPolynomialEvaluationEncoder(Encoder):
 
         - ``other`` -- another Gabidulin Polynomial Evaluation Encoder
 
-        OUTPUT:
-
-        - ``True`` or ``False``
+        OUTPUT: boolean
 
         EXAMPLES::
 
@@ -666,7 +660,7 @@ class GabidulinPolynomialEvaluationEncoder(Encoder):
         C = self.code()
         return C.base_field()['x', C.twisting_homomorphism()]
 
-    def encode(self, p, form="vector"):
+    def encode(self, p, form='vector'):
         """
         Transform the polynomial ``p`` into a codeword of :meth:`code`.
 
@@ -680,11 +674,9 @@ class GabidulinPolynomialEvaluationEncoder(Encoder):
 
         - ``form`` -- type parameter taking strings "vector" or "matrix"
           as values and converting the output codeword into the respective form
-          (default: "vector")
+          (default: ``'vector'``)
 
-        OUTPUT:
-
-        - a codeword corresponding to `p` in vector or matrix form
+        OUTPUT: a codeword corresponding to `p` in vector or matrix form
 
         EXAMPLES::
 
@@ -855,9 +847,7 @@ class GabidulinGaoDecoder(Decoder):
 
         - ``other`` -- another Gabidulin Gao Decoder
 
-        OUTPUT:
-
-        - ``True`` or ``False``
+        OUTPUT: boolean
 
         EXAMPLES::
 
@@ -894,9 +884,7 @@ class GabidulinGaoDecoder(Decoder):
         - ``d_stop`` -- the number of iterations for which the algorithm
           is to be run
 
-        OUTPUT:
-
-        - ``r_c`` -- right linearized remainder of `a` and `b`
+        OUTPUT: ``r_c`` -- right linearized remainder of `a` and `b`
 
         - ``u_c`` -- right linearized quotient of `a` and `b`
 
@@ -995,9 +983,7 @@ class GabidulinGaoDecoder(Decoder):
 
         - ``r`` -- received codeword
 
-        OUTPUT:
-
-        - the decoded codeword corresponding to the received codeword
+        OUTPUT: the decoded codeword corresponding to the received codeword
 
         EXAMPLES::
 
@@ -1028,9 +1014,7 @@ class GabidulinGaoDecoder(Decoder):
 
         - ``r`` -- received codeword
 
-        OUTPUT:
-
-        - the message corresponding to the received codeword
+        OUTPUT: the message corresponding to the received codeword
 
         EXAMPLES::
 
