@@ -122,21 +122,25 @@ AUTHORS:
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
 from __future__ import annotations
-from collections.abc import Iterator
+
 
 from sage.arith.misc import bernoulli, factorial
-from sage.rings.integer_ring import ZZ
-from sage.rings.rational_field import QQ
+from sage.combinat.combinat_cython import _stirling_number2
+from sage.misc.cachefunc import cached_function
+from sage.misc.inherit_comparison import InheritComparisonClasscallMetaclass
+from sage.misc.lazy_import import lazy_import
+from sage.misc.misc_c import prod
 from sage.rings.integer import Integer
+from sage.rings.integer_ring import ZZ
 from sage.rings.polynomial.polynomial_element import Polynomial
 from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
-from sage.misc.misc_c import prod
-from sage.misc.cachefunc import cached_function
-from sage.structure.sage_object import SageObject
-from sage.misc.lazy_import import lazy_import
-from .combinat_cython import _stirling_number2
-from sage.misc.inherit_comparison import InheritComparisonClasscallMetaclass
+from sage.rings.rational_field import QQ
 from sage.structure.element import Element
+from sage.structure.sage_object import SageObject
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from collections.abc import Iterator
 
 lazy_import('sage.interfaces.maxima_lib', 'maxima')
 lazy_import('sage.libs.pari', 'pari')
@@ -339,7 +343,7 @@ def bell_number(n, algorithm='flint', **options) -> Integer:
     if n < 0:
         raise ArithmeticError('Bell numbers not defined for negative indices')
     if algorithm == 'mpmath':
-        from sage.libs.mpmath.all import bell, mp, mag
+        from mpmath import bell, mag, mp
         old_prec = mp.dps
         if 'prec' in options:
             mp.dps = options['prec']
@@ -558,6 +562,8 @@ def eulerian_number(n, k, algorithm='recursive') -> Integer:
         [0, 1, 4, 1, 0]
     """
     n = ZZ(n)
+    if n == 0:
+        return ZZ.one() if k == 0 else ZZ.zero()
     if k < 0 or k > n - 1:
         return ZZ.zero()
     if k == 0 or k == n - 1:
@@ -610,7 +616,7 @@ def eulerian_polynomial(n, algorithm='derivative'):
     R = PolynomialRing(ZZ, 't')
     if n < 0:
         return R.zero()
-    if n == 1:
+    if n <= 1:
         return R.one()
     t = R.gen()
     if algorithm == 'derivative':
@@ -2052,8 +2058,8 @@ def bell_polynomial(n: Integer, k=None, ordinary=False):
     - [Bel1927]_
     - [Com1974]_
     """
-    from sage.combinat.partition import Partitions
     from sage.arith.misc import multinomial
+    from sage.combinat.partition import Partitions
     if k is None:
         partitions = Partitions(n)
         # We set k = 1 to use the correct ring
