@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 r"""
 Integer compositions
 
@@ -46,10 +45,13 @@ from sage.rings.integer import Integer
 from sage.combinat.combinatorial_map import combinatorial_map
 from sage.misc.persist import register_unpickle_override
 
+from sage.misc.lazy_import import lazy_import
+lazy_import("sage.combinat.partition", "Partition")
+
 
 class Composition(CombinatorialElement):
     r"""
-    Integer compositions
+    Integer compositions.
 
     A composition of a nonnegative integer `n` is a list
     `(i_1, \ldots, i_k)` of positive integers with total sum `n`.
@@ -153,10 +155,25 @@ class Composition(CombinatorialElement):
             [1, 0, 0, 0, 1, 1, 0, 1, 0, 0, 1, 0, 0, 0, 0]
             sage: Composition(code=_)
             [4, 1, 2, 3, 5]
+
+        TESTS:
+
+        Let us check that :issue:`14862` is solved::
+
+            sage: C = Compositions()
+            sage: C([3,-1,1])
+            Traceback (most recent call last):
+            ...
+            ValueError: not a composition
+            sage: C("strawberry")
+            Traceback (most recent call last):
+            ...
+            ValueError: not a composition
         """
         if descents is not None:
             if isinstance(descents, tuple):
-                return Compositions().from_descents(descents[0], nps=descents[1])
+                return Compositions().from_descents(descents[0],
+                                                    nps=descents[1])
             else:
                 return Compositions().from_descents(descents)
         elif code is not None:
@@ -165,25 +182,40 @@ class Composition(CombinatorialElement):
             return Compositions().from_subset(*from_subset)
         elif isinstance(co, Composition):
             return co
-        else:
-            return Compositions()(list(co))
+
+        return Compositions()(co)
+
+    def __init__(self, parent, lst):
+        """
+        Initialize ``self``.
+
+        EXAMPLES::
+
+            sage: C = Composition([3,1,2])
+            sage: TestSuite(C).run()
+        """
+        lst = [Integer(u) for u in lst]
+        if not all(u >= 0 for u in lst):
+            raise ValueError("elements must be nonnegative integers")
+        CombinatorialElement.__init__(self, parent, lst)
 
     def _ascii_art_(self):
         """
         TESTS::
 
-            sage: ascii_art(Compositions(4).list())                                     # optional - sage.combinat
+            sage: # needs sage.combinat
+            sage: ascii_art(Compositions(4).list())
             [ *                                  ]
             [ *  **   *        *                 ]
             [ *  *   **  ***   *   **    *       ]
             [ *, * , * , *  , **, ** , ***, **** ]
-            sage: Partitions.options(diagram_str='#', convention="French")              # optional - sage.combinat
-            sage: ascii_art(Compositions(4).list())                                     # optional - sage.combinat
+            sage: Partitions.options(diagram_str='#', convention='French')
+            sage: ascii_art(Compositions(4).list())
             [ #                                  ]
             [ #  #   #        ##                 ]
             [ #  #   ##  #     #  ##   ###       ]
             [ #, ##,  #, ###,  #,  ##,   #, #### ]
-            sage: Partitions.options._reset()                                           # optional - sage.combinat
+            sage: Partitions.options._reset()
         """
         from sage.typeset.ascii_art import ascii_art
         return ascii_art(self.to_skew_partition())
@@ -192,20 +224,21 @@ class Composition(CombinatorialElement):
         """
         TESTS::
 
-            sage: unicode_art(Compositions(4).list())                                   # optional - sage.combinat
+            sage: # needs sage.combinat
+            sage: unicode_art(Compositions(4).list())
             ⎡ ┌┐                                         ⎤
             ⎢ ├┤  ┌┬┐   ┌┐         ┌┐                    ⎥
             ⎢ ├┤  ├┼┘  ┌┼┤  ┌┬┬┐   ├┤   ┌┬┐    ┌┐        ⎥
             ⎢ ├┤  ├┤   ├┼┘  ├┼┴┘  ┌┼┤  ┌┼┼┘  ┌┬┼┤  ┌┬┬┬┐ ⎥
             ⎣ └┘, └┘ , └┘ , └┘  , └┴┘, └┴┘ , └┴┴┘, └┴┴┴┘ ⎦
-            sage: Partitions.options(diagram_str='#', convention="French")              # optional - sage.combinat
-            sage: unicode_art(Compositions(4).list())                                   # optional - sage.combinat
+            sage: Partitions.options(diagram_str='#', convention='French')
+            sage: unicode_art(Compositions(4).list())
             ⎡ ┌┐                                         ⎤
             ⎢ ├┤  ┌┐   ┌┐         ┌┬┐                    ⎥
             ⎢ ├┤  ├┤   ├┼┐  ┌┐    └┼┤  ┌┬┐   ┌┬┬┐        ⎥
             ⎢ ├┤  ├┼┐  └┼┤  ├┼┬┐   ├┤  └┼┼┐  └┴┼┤  ┌┬┬┬┐ ⎥
             ⎣ └┘, └┴┘,  └┘, └┴┴┘,  └┘,  └┴┘,   └┘, └┴┴┴┘ ⎦
-            sage: Partitions.options._reset()                                           # optional - sage.combinat
+            sage: Partitions.options._reset()
         """
         from sage.typeset.unicode_art import unicode_art
         return unicode_art(self.to_skew_partition())
@@ -254,7 +287,7 @@ class Composition(CombinatorialElement):
         The ribbon shape of the conjugate of `I` is the conjugate of
         the ribbon shape of `I`::
 
-            sage: all( I.conjugate().to_skew_partition()                                # optional - sage.combinat
+            sage: all( I.conjugate().to_skew_partition()                                # needs sage.combinat
             ....:      == I.to_skew_partition().conjugate()
             ....:      for I in Compositions(4) )
             True
@@ -359,7 +392,7 @@ class Composition(CombinatorialElement):
 
         INPUT:
 
-        - ``compositions`` -- a list (or iterable) of compositions
+        - ``compositions`` -- list (or iterable) of compositions
 
         EXAMPLES::
 
@@ -440,8 +473,8 @@ class Composition(CombinatorialElement):
 
         - ``other`` -- composition of same size as ``self``
 
-        - ``check`` -- (default: ``True``) a Boolean determining whether
-          to check the input compositions for having the same size
+        - ``check`` -- boolean (default: ``True``); whether to check the input
+          compositions for having the same size
 
         OUTPUT:
 
@@ -552,12 +585,10 @@ class Composition(CombinatorialElement):
 
         - ``other`` -- composition of same size as ``self``
 
-        - ``check`` -- (default: ``True``) a Boolean determining whether
-          to check the input compositions for having the same size
+        - ``check`` -- boolean (default: ``True``); whether to check the input
+          compositions for having the same size
 
-        OUTPUT:
-
-        - the join of the compositions ``self`` and ``other``
+        OUTPUT: the join of the compositions ``self`` and ``other``
 
         EXAMPLES::
 
@@ -677,12 +708,10 @@ class Composition(CombinatorialElement):
 
         - ``other`` -- composition of same size as ``self``
 
-        - ``check`` -- (default: ``True``) a Boolean determining whether
-          to check the input compositions for having the same size
+        - ``check`` -- boolean (default: ``True``); whether to check the input
+          compositions for having the same size
 
-        OUTPUT:
-
-        - the meet of the compositions ``self`` and ``other``
+        OUTPUT: the meet of the compositions ``self`` and ``other``
 
         EXAMPLES::
 
@@ -919,7 +948,7 @@ class Composition(CombinatorialElement):
 
         INPUT:
 
-        - ``J`` -- A composition such that ``self`` is finer than ``J``
+        - ``J`` -- a composition such that ``self`` is finer than ``J``
 
         OUTPUT:
 
@@ -1047,8 +1076,8 @@ class Composition(CombinatorialElement):
 
         INPUT:
 
-        - ``final`` -- (default: ``True``) whether or not to include the final
-          partial sum, which is always the size of the composition.
+        - ``final`` -- boolean (default: ``True``); whether or not to include
+          the final partial sum, which is always the size of the composition
 
         .. SEEALSO::
 
@@ -1083,8 +1112,8 @@ class Composition(CombinatorialElement):
 
         INPUT:
 
-        - ``final`` -- (default: ``False``) whether or not to include the final
-          partial sum, which is always the size of the composition.
+        - ``final`` -- boolean (default: ``False``); whether or not to include
+          the final partial sum, which is always the size of the composition
 
         .. SEEALSO::
 
@@ -1136,7 +1165,7 @@ class Composition(CombinatorialElement):
 
         INPUT:
 
-        - ``final_descent`` -- (Default: ``False``) a boolean integer
+        - ``final_descent`` -- boolean (default: ``False``)
 
         OUTPUT:
 
@@ -1178,14 +1207,13 @@ class Composition(CombinatorialElement):
 
         EXAMPLES::
 
-            sage: Composition([2,1,3]).to_partition()                                   # optional - sage.combinat
+            sage: Composition([2,1,3]).to_partition()                                   # needs sage.combinat
             [3, 2, 1]
-            sage: Composition([4,2,2]).to_partition()                                   # optional - sage.combinat
+            sage: Composition([4,2,2]).to_partition()                                   # needs sage.combinat
             [4, 2, 2]
-            sage: Composition([]).to_partition()                                        # optional - sage.combinat
+            sage: Composition([]).to_partition()                                        # needs sage.combinat
             []
         """
-        from sage.combinat.partition import Partition
         return Partition(sorted(self, reverse=True))
 
     def to_skew_partition(self, overlap=1):
@@ -1202,15 +1230,16 @@ class Composition(CombinatorialElement):
 
         EXAMPLES::
 
-            sage: Composition([3,4,1]).to_skew_partition()                              # optional - sage.combinat
+            sage: # needs sage.combinat
+            sage: Composition([3,4,1]).to_skew_partition()
             [6, 6, 3] / [5, 2]
-            sage: Composition([3,4,1]).to_skew_partition(overlap=0)                     # optional - sage.combinat
+            sage: Composition([3,4,1]).to_skew_partition(overlap=0)
             [8, 7, 3] / [7, 3]
-            sage: Composition([]).to_skew_partition()                                   # optional - sage.combinat
+            sage: Composition([]).to_skew_partition()
             [] / []
-            sage: Composition([1,2]).to_skew_partition()                                # optional - sage.combinat
+            sage: Composition([1,2]).to_skew_partition()
             [2, 1] / []
-            sage: Composition([2,1]).to_skew_partition()                                # optional - sage.combinat
+            sage: Composition([2,1]).to_skew_partition()
             [2, 2] / [1]
         """
         from sage.combinat.skew_partition import SkewPartition
@@ -1249,10 +1278,10 @@ class Composition(CombinatorialElement):
 
         INPUT:
 
-        -  ``other`` -- composition
+        - ``other`` -- composition
 
-        -  ``overlap`` -- boolean (default: ``False``); if ``True``, the
-           overlapping shuffle product is returned.
+        - ``overlap`` -- boolean (default: ``False``); if ``True``, the
+          overlapping shuffle product is returned
 
         OUTPUT:
 
@@ -1264,9 +1293,9 @@ class Composition(CombinatorialElement):
 
             sage: alph = Composition([2,2])
             sage: beta = Composition([1,1,3])
-            sage: S = alph.shuffle_product(beta); S                                     # optional - sage.combinat
+            sage: S = alph.shuffle_product(beta); S                                     # needs sage.combinat
             Shuffle product of [2, 2] and [1, 1, 3]
-            sage: S.list()                                                              # optional - sage.combinat
+            sage: S.list()                                                              # needs sage.combinat
             [[2, 2, 1, 1, 3], [2, 1, 2, 1, 3], [2, 1, 1, 2, 3], [2, 1, 1, 3, 2],
              [1, 2, 2, 1, 3], [1, 2, 1, 2, 3], [1, 2, 1, 3, 2], [1, 1, 2, 2, 3],
              [1, 1, 2, 3, 2], [1, 1, 3, 2, 2]]
@@ -1275,9 +1304,9 @@ class Composition(CombinatorialElement):
 
             sage: alph = Composition([2,2])
             sage: beta = Composition([1,1,3])
-            sage: O = alph.shuffle_product(beta, overlap=True); O                       # optional - sage.combinat
+            sage: O = alph.shuffle_product(beta, overlap=True); O                       # needs sage.combinat
             Overlapping shuffle product of [2, 2] and [1, 1, 3]
-            sage: O.list()                                                              # optional - sage.combinat
+            sage: O.list()                                                              # needs sage.combinat
             [[2, 2, 1, 1, 3], [2, 1, 2, 1, 3], [2, 1, 1, 2, 3], [2, 1, 1, 3, 2],
              [1, 2, 2, 1, 3], [1, 2, 1, 2, 3], [1, 2, 1, 3, 2], [1, 1, 2, 2, 3],
              [1, 1, 2, 3, 2], [1, 1, 3, 2, 2],
@@ -1290,20 +1319,21 @@ class Composition(CombinatorialElement):
         composition more than once since a composition can be a shuffle of two
         compositions in several ways. For example::
 
+            sage: # needs sage.combinat
             sage: w1 = Composition([1])
-            sage: S = w1.shuffle_product(w1); S                                         # optional - sage.combinat
+            sage: S = w1.shuffle_product(w1); S
             Shuffle product of [1] and [1]
-            sage: S.list()                                                              # optional - sage.combinat
+            sage: S.list()
             [[1, 1], [1, 1]]
-            sage: O = w1.shuffle_product(w1, overlap=True); O                           # optional - sage.combinat
+            sage: O = w1.shuffle_product(w1, overlap=True); O
             Overlapping shuffle product of [1] and [1]
-            sage: O.list()                                                              # optional - sage.combinat
+            sage: O.list()
             [[1, 1], [1, 1], [2]]
 
         TESTS::
 
             sage: empty = Composition([])
-            sage: empty.shuffle_product(empty).list()                                   # optional - sage.combinat
+            sage: empty.shuffle_product(empty).list()                                   # needs sage.combinat
             [[]]
         """
         if overlap:
@@ -1400,10 +1430,10 @@ class Composition(CombinatorialElement):
 
         EXAMPLES::
 
-            sage: SM = Composition([1,2,2]).specht_module(QQ); SM                       # optional - sage.combinat sage.modules
+            sage: SM = Composition([1,2,2]).specht_module(QQ); SM                       # needs sage.combinat sage.modules
             Specht module of [(0, 0), (1, 0), (1, 1), (2, 0), (2, 1)] over Rational Field
-            sage: s = SymmetricFunctions(QQ).s()                                        # optional - sage.combinat sage.modules
-            sage: s(SM.frobenius_image())                                               # optional - sage.combinat sage.modules
+            sage: s = SymmetricFunctions(QQ).s()                                        # needs sage.combinat sage.modules
+            sage: s(SM.frobenius_image())                                               # needs sage.combinat sage.modules
             s[2, 2, 1]
         """
         from sage.combinat.specht_module import SpechtModule
@@ -1412,10 +1442,7 @@ class Composition(CombinatorialElement):
             from sage.rings.rational_field import QQ
             base_ring = QQ
         R = SymmetricGroupAlgebra(base_ring, sum(self))
-        cells = []
-        for i, row in enumerate(self):
-            for j in range(row):
-                cells.append((i, j))
+        cells = [(i, j) for i, row in enumerate(self) for j in range(row)]
         return SpechtModule(R, cells)
 
     def specht_module_dimension(self, base_ring=None):
@@ -1428,9 +1455,9 @@ class Composition(CombinatorialElement):
 
         EXAMPLES::
 
-            sage: Composition([1,2,2]).specht_module_dimension()                        # optional - sage.combinat sage.modules
+            sage: Composition([1,2,2]).specht_module_dimension()                        # needs sage.combinat sage.modules
             5
-            sage: Composition([1,2,2]).specht_module_dimension(GF(2))                   # optional - sage.combinat sage.modules sage.rings.finite_rings
+            sage: Composition([1,2,2]).specht_module_dimension(GF(2))                   # needs sage.combinat sage.modules sage.rings.finite_rings
             5
         """
         from sage.combinat.specht_module import specht_module_rank
@@ -1479,10 +1506,10 @@ class Compositions(UniqueRepresentation, Parent):
         [1, 2, 1]
 
     If `n` is not specified, this returns the combinatorial class of
-    all (non-negative) integer compositions::
+    all (nonnegative) integer compositions::
 
         sage: Compositions()
-        Compositions of non-negative integers
+        Compositions of nonnegative integers
         sage: [] in Compositions()
         True
         sage: [2,3,1] in Compositions()
@@ -1750,9 +1777,13 @@ class Compositions(UniqueRepresentation, Parent):
             sage: P = Compositions()
             sage: P([3,3,1]) # indirect doctest
             [3, 3, 1]
+            sage: P(Partition([5,2,1]))
+            [5, 2, 1]
         """
-        if isinstance(lst, Composition):
-            lst = list(lst)
+        # input can be an iterator, and one has to use it twice
+        lst = list(lst)
+        if any(not isinstance(x, (int, Integer)) or x < 0 for x in lst):
+            raise ValueError('not a composition')
         elt = self.element_class(self, lst)
         if elt not in self:
             raise ValueError("%s not in %s" % (elt, self))
@@ -1771,7 +1802,7 @@ class Compositions(UniqueRepresentation, Parent):
             sage: [0,0] in Compositions()
             True
         """
-        if isinstance(x, Composition):
+        if isinstance(x, (Composition, Partition)):
             return True
         elif isinstance(x, list):
             for i in x:
@@ -1791,7 +1822,7 @@ class Compositions(UniqueRepresentation, Parent):
 
         - ``descents`` -- an iterable
 
-        - ``nps`` -- (default: ``None``) an integer or ``None``
+        - ``nps`` -- integer or ``None`` (default: ``None``)
 
         OUTPUT:
 
@@ -1826,7 +1857,7 @@ class Compositions(UniqueRepresentation, Parent):
 
         - ``S`` -- an iterable, a subset of `\{1, 2, \ldots, n-1\}`
 
-        - ``n`` -- an integer
+        - ``n`` -- integer
 
         EXAMPLES::
 
@@ -1856,13 +1887,13 @@ class Compositions(UniqueRepresentation, Parent):
                 return self.element_class(self, [n])
 
         if n <= d[-1]:
-            raise ValueError("S (=%s) is not a subset of {1, ..., %s}" % (d, n - 1))
+            raise ValueError("S (=%s) is not a subset of {1, ..., %s}"
+                             % (d, n - 1))
         else:
             d.append(n)
 
         co = [d[0]]
-        for i in range(len(d) - 1):
-            co.append(d[i + 1] - d[i])
+        co.extend(d[i + 1] - d[i] for i in range(len(d) - 1))
 
         return self.element_class(self, co)
 
@@ -1941,9 +1972,9 @@ class Compositions_all(Compositions):
         TESTS::
 
             sage: repr(Compositions())
-            'Compositions of non-negative integers'
+            'Compositions of nonnegative integers'
         """
-        return "Compositions of non-negative integers"
+        return "Compositions of nonnegative integers"
 
     def subset(self, size=None):
         """
@@ -2126,7 +2157,7 @@ class Compositions_n(Compositions):
 
 def composition_iterator_fast(n):
     """
-    Iterator over compositions of ``n`` yielded as lists.
+    Iterator over compositions of `n` yielded as lists.
 
     TESTS::
 
