@@ -292,7 +292,7 @@ class GroupDivisibleDesign(IncidenceStructure):
 
         if check or groups is None:
             is_gdd = is_group_divisible_design(self._groups, self._blocks,
-                                               self.num_points(), G, K,
+                                               self.n_points(), G, K,
                                                lambd, verbose=1)
             assert is_gdd
             if groups is None:
@@ -355,6 +355,6 @@ class GroupDivisibleDesign(IncidenceStructure):
         if not gdd_type:
             gdd_type = "1^0"
 
-        v = self.num_points()
+        v = self.n_points()
 
         return "Group Divisible Design on {} points of type {}".format(v, gdd_type)
