@@ -1,15 +1,5 @@
 r"""
-Linear Extensions of Posets
-
-This module defines two classes:
-
-- :class:`LinearExtensionOfPoset`
-- :class:`LinearExtensionsOfPoset`
-- :class:`LinearExtensionsOfPosetWithHooks`
-- :class:`LinearExtensionsOfForest`
-
-Classes and methods
--------------------
+Linear extensions of posets
 """
 # ****************************************************************************
 #       Copyright (C) 2012 Anne Schilling <anne at math.ucdavis.edu>
@@ -130,7 +120,7 @@ class LinearExtensionOfPoset(ClonableArray,
             return linear_extension
         return LinearExtensionsOfPoset(poset)(linear_extension)
 
-    def check(self):
+    def check(self) -> None:
         r"""
         Check whether ``self`` is indeed a linear extension of the underlying poset.
 
@@ -161,7 +151,7 @@ class LinearExtensionOfPoset(ClonableArray,
         """
         return self.parent().poset()
 
-    def _latex_(self):
+    def _latex_(self) -> str:
         r"""
         Return the latex string for ``self``.
 
@@ -217,12 +207,12 @@ class LinearExtensionOfPoset(ClonableArray,
             True
         """
         P = self.parent().poset()
-        old = [P.unwrap(x) for x in self]
+        old = (P.unwrap(x) for x in self)
         new = [P.unwrap(x) for x in P]
         relabelling = dict(zip(old, new))
         return P.relabel(relabelling).with_linear_extension(new)
 
-    def is_greedy(self):
+    def is_greedy(self) -> bool:
         r"""
         Return ``True`` if the linear extension is greedy.
 
@@ -256,7 +246,7 @@ class LinearExtensionOfPoset(ClonableArray,
                         return False
         return True
 
-    def is_supergreedy(self):
+    def is_supergreedy(self) -> bool:
         r"""
         Return ``True`` if the linear extension is supergreedy.
 
@@ -430,7 +420,7 @@ class LinearExtensionOfPoset(ClonableArray,
                 self = self.tau(j)
         return self
 
-    def jump_count(self):
+    def jump_count(self) -> int:
         r"""
         Return the number of jumps in the linear extension.
 
@@ -550,7 +540,7 @@ class LinearExtensionsOfPoset(UniqueRepresentation, Parent):
             facade = (list,)
         Parent.__init__(self, category=FiniteEnumeratedSets(), facade=facade)
 
-    def _repr_(self):
+    def _repr_(self) -> str:
         """
         TESTS::
 
@@ -709,7 +699,7 @@ class LinearExtensionsOfPoset(UniqueRepresentation, Parent):
         return (isinstance(obj, (list, tuple)) and
                 self.poset().is_linear_extension(obj))
 
-    def markov_chain_digraph(self, action='promotion', labeling='identity'):
+    def markov_chain_digraph(self, action='promotion', labeling='identity') -> DiGraph:
         r"""
         Return the digraph of the action of generalized promotion or tau on ``self``.
 
@@ -907,11 +897,10 @@ class LinearExtensionsOfPoset(UniqueRepresentation, Parent):
             lst = list(lst)
         if not isinstance(lst, (list, tuple)):
             raise TypeError("input should be a list or tuple")
-        lst = [self._poset(_) for _ in lst]
+        lst = [self._poset(e) for e in lst]
         if self._is_facade:
             return lst
-        else:
-            return self.element_class(self, lst, check)
+        return self.element_class(self, lst, check)
 
     Element = LinearExtensionOfPoset
 
