@@ -1,6 +1,6 @@
 # sage.doctest: needs sage.modules
 r"""
-Möbius Algebras
+Möbius algebras
 """
 # ****************************************************************************
 #       Copyright (C) 2014 Travis Scrimshaw <tscrim at ucdavis.edu>,
@@ -113,7 +113,7 @@ class MoebiusAlgebra(Parent, UniqueRepresentation):
         self._category = cat
         Parent.__init__(self, base=R, category=self._category.WithRealizations())
 
-    def _repr_(self):
+    def _repr_(self) -> str:
         """
         Return a string representation of ``self``.
 
@@ -411,7 +411,7 @@ class QuantumMoebiusAlgebra(Parent, UniqueRepresentation):
         self._category = cat
         Parent.__init__(self, base=R, category=self._category.WithRealizations())
 
-    def _repr_(self):
+    def _repr_(self) -> str:
         """
         Return a string representation of ``self``.
 
@@ -693,7 +693,7 @@ class MoebiusAlgebraBases(Category_realization_of_parent):
         sage: M.E() in bases
         True
     """
-    def _repr_(self):
+    def _repr_(self) -> str:
         r"""
         Return the representation of ``self``.
 
@@ -724,7 +724,7 @@ class MoebiusAlgebraBases(Category_realization_of_parent):
         return [self.base()._category, Realizations(self.base())]
 
     class ParentMethods:
-        def _repr_(self):
+        def _repr_(self) -> str:
             """
             Text representation of this basis of a Möbius algebra.
 
