@@ -349,7 +349,7 @@ class Algebras(AlgebrasCategory):
                 sage: KL.demazure_lusztig_operator_on_basis(L((3,0)), 1, q1, q2)
                 (q1+q2)*B[(1, 2)] + (q1+q2)*B[(2, 1)] + (q1+q2)*B[(3, 0)] + q1*B[(0, 3)]
                 sage: KL.demazure_lusztig_operator_on_basis(L((0,3)), 1, q1, q2)
-                (-q1-q2)*B[(1, 2)] + (-q1-q2)*B[(2, 1)] + (-q2)*B[(3, 0)]
+                -(q1+q2)*B[(1, 2)] - (q1+q2)*B[(2, 1)] - q2*B[(3, 0)]
 
             At `q_1=1` and `q_2=0` we recover the action of the isobaric divided differences `\pi_i`::
 
@@ -455,14 +455,14 @@ class Algebras(AlgebrasCategory):
                 sage: T[1](x)
                 (q1+q2)*B[(1, 2)] + (q1+q2)*B[(2, 1)] + (q1+q2)*B[(3, 0)] + q1*B[(0, 3)]
                 sage: Tbar[1](x)
-                (-q1-q2)*B[(1, 2)] + (-q1-q2)*B[(2, 1)] + (-q1-2*q2)*B[(0, 3)]
+                -(q1+q2)*B[(1, 2)] - (q1+q2)*B[(2, 1)] - (q1+2*q2)*B[(0, 3)]
                 sage: Tbar[1](x) + T[1](x)
-                (q1+q2)*B[(3, 0)] + (-2*q2)*B[(0, 3)]
+                (q1+q2)*B[(3, 0)] - 2*q2*B[(0, 3)]
                 sage: Tdominant[1](x)
-                (-q1-q2)*B[(1, 2)] + (-q1-q2)*B[(2, 1)] + (-q2)*B[(0, 3)]
+                -(q1+q2)*B[(1, 2)] - (q1+q2)*B[(2, 1)] - q2*B[(0, 3)]
 
                 sage: Tdominant.Tw_inverse(1)(KL.monomial(-L.simple_root(1)))
-                ((-q1-q2)/(q1*q2))*B[(0, 0)] - 1/q2*B[(1, -1)]
+                -((q1+q2)/(q1*q2))*B[(0, 0)] - 1/q2*B[(1, -1)]
 
             We repeat similar computation in the affine setting::
 
@@ -480,14 +480,13 @@ class Algebras(AlgebrasCategory):
                 (q1+q2)*B[e[0] + 2*e[1]] + (q1+q2)*B[2*e[0] + e[1]]
                  + (q1+q2)*B[3*e[0]] + q1*B[3*e[1]]
                 sage: Tbar[1](x)
-                (-q1-q2)*B[e[0] + 2*e[1]] + (-q1-q2)*B[2*e[0] + e[1]]
-                 + (-q1-2*q2)*B[3*e[1]]
+                -(q1+q2)*B[e[0] + 2*e[1]] - (q1+q2)*B[2*e[0] + e[1]] - (q1+2*q2)*B[3*e[1]]
                 sage: Tbar[1](x) + T[1](x)
-                (q1+q2)*B[3*e[0]] + (-2*q2)*B[3*e[1]]
+                (q1+q2)*B[3*e[0]] - 2*q2*B[3*e[1]]
                 sage: Tdominant[1](x)
-                (-q1-q2)*B[e[0] + 2*e[1]] + (-q1-q2)*B[2*e[0] + e[1]] + (-q2)*B[3*e[1]]
+                -(q1+q2)*B[e[0] + 2*e[1]] - (q1+q2)*B[2*e[0] + e[1]] - q2*B[3*e[1]]
                 sage: Tdominant.Tw_inverse(1)(KL.monomial(-L.simple_root(1)))
-                ((-q1-q2)/(q1*q2))*B[0] - 1/q2*B[e[0] - e[1]]
+                -((q1+q2)/(q1*q2))*B[0] - 1/q2*B[e[0] - e[1]]
 
             One can obtain iterated operators by passing a reduced
             word or an element of the Weyl group::
@@ -544,19 +543,19 @@ class Algebras(AlgebrasCategory):
                 sage: Y[alphacheck[0]](KL.one())
                 q2^2/q1^2*B[0]
                 sage: Y[alphacheck[1]](x)
-                ((-q2^2)/(-q1^2))*B[e[0] - e['delta']]
+                -(q2^2/(-q1^2))*B[e[0] - e['delta']]
                 sage: Y[alphacheck[2]](x)
                 (q1/(-q2))*B[e[0]]
                 sage: KL.q_project(Y[alphacheck[1]](x),q)
-                ((-q2^2)/(-q*q1^2))*B[(1, 0, 0)]
+                -(q2^2/(-q*q1^2))*B[(1, 0, 0)]
 
                 sage: # needs sage.graphs
                 sage: KL.q_project(x, q)
                 B[(1, 0, 0)]
                 sage: KL.q_project(Y[alphacheck[0]](x),q)
-                ((-q*q1)/q2)*B[(1, 0, 0)]
+                -q*q1/q2*B[(1, 0, 0)]
                 sage: KL.q_project(Y[alphacheck[1]](x),q)
-                ((-q2^2)/(-q*q1^2))*B[(1, 0, 0)]
+                -(q2^2/(-q*q1^2))*B[(1, 0, 0)]
                 sage: KL.q_project(Y[alphacheck[2]](x),q)
                 (q1/(-q2))*B[(1, 0, 0)]
 
@@ -646,7 +645,7 @@ class Algebras(AlgebrasCategory):
                 q1*B[(2, 2)]
                 sage: KL.demazure_lusztig_operator_on_classical_on_basis(L0((3,0)),     # needs sage.graphs
                 ....:                                                    0, q, q1, q2)
-                (-q^2*q1-q^2*q2)*B[(1, 2)] + (-q*q1-q*q2)*B[(2, 1)] + (-q^3*q2)*B[(0, 3)]
+                -(q^2*q1+q^2*q2)*B[(1, 2)] - (q*q1+q*q2)*B[(2, 1)] - q^3*q2*B[(0, 3)]
             """
             L = self.basis().keys()
             weight = L.embed_at_level(weight, 0)
@@ -695,7 +694,7 @@ class Algebras(AlgebrasCategory):
             is mapped to `q`::
 
                 sage: T[0](x)                                                           # needs sage.graphs
-                (-q^2*q1-q^2*q2)*B[(1, 2)] + (-q*q1-q*q2)*B[(2, 1)] + (-q^3*q2)*B[(0, 3)]
+                -(q^2*q1+q^2*q2)*B[(1, 2)] - (q*q1+q*q2)*B[(2, 1)] - q^3*q2*B[(0, 3)]
 
             Note that there is no translation part, and in particular
             1 is an eigenvector for all `T_i`'s::
@@ -708,7 +707,7 @@ class Algebras(AlgebrasCategory):
                 sage: Y = T.Y()
                 sage: alphacheck = Y.keys().simple_roots()
                 sage: Y[alphacheck[0]](KL0.one())
-                ((-q2)/(q*q1))*B[(0, 0)]
+                -q2/(q*q1)*B[(0, 0)]
 
             Matching with Ion Bogdan's hand calculations from 3/15/2013::
 
@@ -746,7 +745,7 @@ class Algebras(AlgebrasCategory):
                 sage: T0(KL0.monomial(-omega[1]))
                 1/(q*u)*B[Lambda[1]]
                 sage: T0(KL0.monomial(-2*omega[1]))
-                ((-u^2+1)/(q*u))*B[0] + 1/(q^2*u)*B[2*Lambda[1]]
+                -((u^2-1)/(q*u))*B[0] + 1/(q^2*u)*B[2*Lambda[1]]
             """
             # In type BC dual we used q^2 and q elsewhere
             # Not sure this is the right thing to do or just a workaround ...
@@ -992,10 +991,10 @@ class Algebras(AlgebrasCategory):
                 sage: Lambda = L.classical().fundamental_weights()
                 sage: KL.twisted_demazure_lusztig_operator_on_basis(
                 ....:     Lambda[1] + 2*Lambda[2], 1, q1, q2, convention='dominant')
-                (-q2)*B[(2, 3, 0, 0)]
+                -q2*B[(2, 3, 0, 0)]
                 sage: KL.twisted_demazure_lusztig_operator_on_basis(
                 ....:     Lambda[1] + 2*Lambda[2], 2, q1, q2, convention='dominant')
-                (-q1-q2)*B[(3, 1, 1, 0)] + (-q2)*B[(3, 0, 2, 0)]
+                -(q1+q2)*B[(3, 1, 1, 0)] - q2*B[(3, 0, 2, 0)]
                 sage: KL.twisted_demazure_lusztig_operator_on_basis(
                 ....:     Lambda[1] + 2*Lambda[2], 3, q1, q2, convention='dominant')
                 q1*B[(3, 2, 0, 0)]
@@ -1060,7 +1059,7 @@ class Algebras(AlgebrasCategory):
                 sage: T.Ti_inverse_on_basis(L0.zero(), 1)
                 1/q1*B[(0, 0)]
                 sage: T.Ti_on_basis(alpha[1], 1)
-                (-q1-q2)*B[(0, 0)] + (-q2)*B[(-1, 1)]
+                -(q1+q2)*B[(0, 0)] - q2*B[(-1, 1)]
                 sage: T.Ti_inverse_on_basis(alpha[1], 1)
                 ((q1+q2)/(q1*q2))*B[(0, 0)] + 1/q1*B[(-1, 1)] + ((q1+q2)/(q1*q2))*B[(1, -1)]
                 sage: T.Ti_on_basis(L0.zero(), 0)                                       # needs sage.graphs
@@ -1141,7 +1140,7 @@ class Algebras(AlgebrasCategory):
                 sage: def T0c(*l0): return T0_check_on_basis(L0(l0))
 
                 sage: T0(0,0,1)                                 # not double checked    # needs sage.graphs
-                ((-t+1)/q)*B[(1, 0, 0)] + 1/q^2*B[(2, 0, -1)]
+                -((t-1)/q)*B[(1, 0, 0)] + 1/q^2*B[(2, 0, -1)]
                 sage: T0c(0,0,1)                                                        # needs sage.graphs
                 (t^2-t)*B[(1, 0, 0)] + (t^2-t)*B[(1, 1, -1)] + t^2*B[(2, 0, -1)] + (t-1)*B[(0, 0, 1)]
             """
