@@ -17,20 +17,18 @@ Classical symmetric functions
 #
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
+from sage.combinat.partition import _Partitions
 from sage.rings.integer import Integer
 from sage.rings.integer_ring import ZZ
 from sage.rings.rational_field import QQ
-from sage.combinat.partition import _Partitions
 
+from . import hall_littlewood, jack, llt, macdonald, orthotriang, sfa
 
-from . import hall_littlewood
-from . import sfa
-from . import llt
-from . import macdonald
-from . import jack
-from . import orthotriang
-
-translate = {'monomial':'MONOMIAL', 'homogeneous':'HOMSYM', 'powersum':'POWSYM', 'elementary':'ELMSYM', 'Schur':'SCHUR'}
+translate = {'monomial': 'MONOMIAL',
+             'homogeneous': 'HOMSYM',
+             'powersum': 'POWSYM',
+             'elementary': 'ELMSYM',
+             'Schur': 'SCHUR'}
 
 conversion_functions = {}
 
@@ -45,7 +43,7 @@ def init():
         sage: sage.combinat.sf.classical.conversion_functions = {}
         sage: init()
         sage: sage.combinat.sf.classical.conversion_functions[('Schur', 'powersum')]
-        <built-in function t_SCHUR_POWSYM_symmetrica>
+        <cyfunction t_SCHUR_POWSYM_symmetrica at ...>
 
     The following checks if the bug described in :issue:`15312` is fixed. ::
 
@@ -55,11 +53,11 @@ def init():
         s[1, 1, 1, 1] - s[2, 1, 1] + 2*s[2, 2] - s[3, 1] + s[4]
     """
     import sage.libs.symmetrica.all as symmetrica
-    for other_basis in translate:
-        for basis in translate:
+    for other_basis, other_name in translate.items():
+        for basis, name in translate.items():
             try:
                 conversion_functions[(other_basis, basis)] = getattr(symmetrica,
-                     't_{}_{}'.format(translate[other_basis], translate[basis]))
+                        f't_{other_name}_{name}')
             except AttributeError:
                 pass
 
