@@ -101,7 +101,7 @@ similarity classes of `k`-tuples of `n\times n` matrices with entries in
 
     sage: from sage.combinat.similarity_class_type import order_of_general_linear_group, centralizer_algebra_dim
     sage: q = ZZ['q'].gen()
-    sage: def simultaneous_similarity_classes(n,k):
+    sage: def simultaneous_similarity_classes(n, k):
     ....:     return SimilarityClassTypes(n).sum(lambda la: q**(k*centralizer_algebra_dim(la)), invertible = True)/order_of_general_linear_group(n)
     sage: simultaneous_similarity_classes(3, 2)
     q^10 + q^8 + 2*q^7 + 2*q^6 + 2*q^5 + q^4
@@ -215,13 +215,11 @@ def fq(n, q=None):
 
     INPUT:
 
-    - ``n`` -- a non-negative integer
+    - ``n`` -- nonnegative integer
 
-    - ``q`` -- an integer or an indeterminate
+    - ``q`` -- integer or an indeterminate
 
-    OUTPUT:
-
-    A rational function in ``q``.
+    OUTPUT: a rational function in ``q``
 
     EXAMPLES::
 
@@ -253,15 +251,13 @@ def primitives(n, invertible=False, q=None):
 
     INPUT:
 
-    - ``n`` -- a positive integer
+    - ``n`` -- positive integer
 
-    - ``invertible`` -- boolean; if set, only number of non-zero classes is returned
+    - ``invertible`` -- boolean; if set, only number of nonzero classes is returned
 
-    - ``q`` -- an integer or an indeterminate
+    - ``q`` -- integer or an indeterminate
 
-    OUTPUT:
-
-    - a rational function of the variable ``q``
+    OUTPUT: a rational function of the variable ``q``
 
     EXAMPLES::
 
@@ -292,9 +288,9 @@ def order_of_general_linear_group(n, q=None):
 
     INPUT:
 
-    - ``n`` -- a non-negative integer
+    - ``n`` -- nonnegative integer
 
-    - ``q`` -- an integer or an indeterminate
+    - ``q`` -- integer or an indeterminate
 
     EXAMPLES::
 
@@ -340,9 +336,7 @@ def centralizer_group_cardinality(la, q=None):
 
     - ``q`` -- an integer or an indeterminate
 
-    OUTPUT:
-
-    A polynomial function of ``q``.
+    OUTPUT: a polynomial function of ``q``
 
     EXAMPLES::
 
@@ -367,9 +361,7 @@ def invariant_subspace_generating_function(la, q=None, t=None):
     - ``q`` -- (optional) an integer or an inderminate
     - ``t`` -- (optional) an indeterminate
 
-    OUTPUT:
-
-    A polynomial in ``t`` whose coefficients are polynomials in ``q``.
+    OUTPUT: a polynomial in ``t`` whose coefficients are polynomials in ``q``
 
     EXAMPLES::
 
@@ -588,7 +580,7 @@ class PrimarySimilarityClassType(Element,
 
         INPUT:
 
-        - ``q`` -- an integer or an indeterminate
+        - ``q`` -- integer or an indeterminate
 
         EXAMPLES::
 
@@ -637,7 +629,7 @@ class PrimarySimilarityClassTypes(UniqueRepresentation, Parent):
 
     INPUT:
 
-    - ``n`` -- a positive integer
+    - ``n`` -- positive integer
     - ``min`` -- a primary matrix type of size ``n``
 
     EXAMPLES:
@@ -767,7 +759,7 @@ class SimilarityClassType(CombinatorialElement):
 
     INPUT:
 
-    - ``tau`` -- a list of primary similarity class types or a square matrix
+    - ``tau`` -- list of primary similarity class types or a square matrix
       over a finite field
 
     EXAMPLES::
@@ -872,7 +864,7 @@ class SimilarityClassType(CombinatorialElement):
 
         INPUT:
 
-        - ``q`` -- an integer or an indeterminate
+        - ``q`` -- integer or an indeterminate
 
         EXAMPLES::
 
@@ -908,10 +900,10 @@ class SimilarityClassType(CombinatorialElement):
 
         INPUT:
 
-        - ``invertible`` -- Boolean; return number of invertible classes if set
+        - ``invertible`` -- boolean; return number of invertible classes if set
           to ``True``
 
-        - ``q`` -- An integer or an indeterminate
+        - ``q`` -- integer or an indeterminate
 
         EXAMPLES::
 
@@ -927,11 +919,11 @@ class SimilarityClassType(CombinatorialElement):
         maximum_degree = max(list_of_degrees)
         numerator = prod([prod([primitives(d+1, invertible=invertible, q=q)-i for i in range(list_of_degrees.count(d+1))]) for d in range(maximum_degree)])
         tau_list = list(self)
-        D = dict((i, tau_list.count(i)) for i in tau_list)
+        D = {i: tau_list.count(i) for i in tau_list}
         denominator = prod(factorial(D[primary_type]) for primary_type in D)
         return numerator / denominator
 
-    def is_semisimple(self):
+    def is_semisimple(self) -> bool:
         """
         Return ``True`` if every primary similarity class type in ``self`` has
         all parts equal to ``1``.
@@ -947,7 +939,7 @@ class SimilarityClassType(CombinatorialElement):
         """
         return all(PT.partition().get_part(0) == 1 for PT in self)
 
-    def is_regular(self):
+    def is_regular(self) -> bool:
         """
         Return ``True`` if every primary type in ``self`` has partition with one
         part.
@@ -990,7 +982,7 @@ class SimilarityClassType(CombinatorialElement):
 
         INPUT:
 
-        - ``q`` -- an integer or an indeterminate
+        - ``q`` -- integer or an indeterminate
 
         EXAMPLES::
 
@@ -1011,7 +1003,7 @@ class SimilarityClassType(CombinatorialElement):
 
         INPUT:
 
-        - ``invertible`` -- A boolean; return the number of invertible
+        - ``invertible`` -- a boolean; return the number of invertible
           matrices if set
 
         EXAMPLES::
@@ -1031,7 +1023,7 @@ class SimilarityClassType(CombinatorialElement):
 
     def statistic(self, func, q=None):
         r"""
-        Return
+        Return.
 
         .. MATH::
 
@@ -1044,7 +1036,7 @@ class SimilarityClassType(CombinatorialElement):
 
         - ``func`` -- a function that takes a partition to a polynomial in ``q``
 
-        - ``q`` -- an integer or an indeterminate
+        - ``q`` -- integer or an indeterminate
 
         EXAMPLES::
 
@@ -1100,7 +1092,7 @@ class SimilarityClassTypes(UniqueRepresentation, Parent):
 
     INPUT:
 
-    - ``n`` -- a non-negative integer
+    - ``n`` -- nonnegative integer
     - ``min`` -- a primary similarity class type
 
     EXAMPLES:
@@ -1168,7 +1160,7 @@ class SimilarityClassTypes(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - ``tau`` -- a list of primary similarity class types
+        - ``tau`` -- list of primary similarity class types
 
         EXAMPLES::
 
@@ -1238,7 +1230,7 @@ class SimilarityClassTypes(UniqueRepresentation, Parent):
         """
         return self._n
 
-    def sum(self, stat, sumover="matrices", invertible=False, q=None):
+    def sum(self, stat, sumover='matrices', invertible=False, q=None):
         r"""
         Return the sum of a local statistic over all types.
 
@@ -1256,10 +1248,10 @@ class SimilarityClassTypes(UniqueRepresentation, Parent):
             \sum n_{\tau(g)}(q)
 
         where `\tau(g)` denotes the type of a matrix `g`, and the sum is over
-        all `n \times n` matrices if ``sumover`` is set to ``"matrices"``, is
+        all `n \times n` matrices if ``sumover`` is set to ``'matrices'``, is
         over all `n \times n` similarity classes if ``sumover`` is set to
-        ``"classes"``, and over all `n \times n` types if ``sumover`` is set
-        to ``"types"``. If ``invertible`` is set to ``True``, then the sum is
+        ``'classes'``, and over all `n \times n` types if ``sumover`` is set
+        to ``'types'``. If ``invertible`` is set to ``True``, then the sum is
         only over invertible matrices or classes.
 
         INPUT:
@@ -1268,15 +1260,13 @@ class SimilarityClassTypes(UniqueRepresentation, Parent):
           of ``q``
         - ``sumover`` -- can be one of the following:
 
-          * ``"matrices"``
-          * ``"classes"``
-          * ``"types"``
+          * ``'matrices'``
+          * ``'classes'``
+          * ``'types'``
 
-        - ``q`` -- an integer or an indeterminate
+        - ``q`` -- integer or an indeterminate
 
-        OUTPUT:
-
-        A function of ``q``.
+        OUTPUT: a function of ``q``
 
         EXAMPLES::
 
@@ -1335,8 +1325,9 @@ def dictionary_from_generator(gen):
         high.
     """
     L = list(gen)
-    setofkeys = list(set(item[0] for item in L))
-    return dict((key, sum(entry[1] for entry in (pair for pair in L if pair[0] == key))) for key in setofkeys)
+    setofkeys = set(item[0] for item in L)
+    return {key: sum(pair[1] for pair in L if pair[0] == key)
+            for key in setofkeys}
 
 
 def matrix_similarity_classes(n, q=None, invertible=False):
@@ -1445,8 +1436,8 @@ def ext_orbits(input_data, q=None, selftranspose=False):
 
     - ``input_data`` -- input for :func:`input_parsing()`
     - ``q`` -- (default: `q`) an integer or an indeterminate
-    - ``selftranspose`` -- (default: ``False``) boolean stating if we only want
-      selftranspose type
+    - ``selftranspose`` -- boolean (default: ``False``); stating if we only
+      want selftranspose type
 
     TESTS::
 
@@ -1522,9 +1513,9 @@ def matrix_similarity_classes_length_two(n, q=None, selftranspose=False, inverti
 
     - ``n`` -- the order
     - ``q`` -- (default: `q`) an integer or an indeterminate
-    - ``selftranspose`` -- (default: ``False``) boolean stating if we only want
+    - ``selftranspose`` -- boolean (default: ``False``); stating if we only want
       selftranspose type
-    - ``invertible`` -- (default: ``False``) boolean stating if we only want
+    - ``invertible`` -- boolean (default: ``False``); stating if we only want
       invertible type
 
     EXAMPLES:
@@ -1575,7 +1566,7 @@ def ext_orbit_centralizers(input_data, q=None, selftranspose=False):
 
     - ``input_data`` -- input for :func:`input_parsing()`
     - ``q`` -- (default: `q`) an integer or an indeterminate
-    - ``selftranspose`` -- (default: ``False``) boolean stating if we only want
+    - ``selftranspose`` -- boolean (default: ``False``); stating if we only want
       selftranspose type
 
     TESTS::
@@ -1700,9 +1691,9 @@ def matrix_centralizer_cardinalities_length_two(n, q=None, selftranspose=False,
 
     - ``n`` -- the order
     - ``q`` -- (default: `q`) an integer or an indeterminate
-    - ``selftranspose`` -- (default: ``False``) boolean stating if we only want
+    - ``selftranspose`` -- boolean (default: ``False``); stating if we only want
       selftranspose type
-    - ``invertible`` -- (default: ``False``) boolean stating if we only want
+    - ``invertible`` -- boolean (default: ``False``); stating if we only want
       invertible type
 
     TESTS::
