@@ -1,28 +1,6 @@
-# sage_setup: distribution = sagemath-environment
 r"""
 Sage Runtime Environment
 
-Verify that importing ``sage.all`` works in Sage's Python without any
-``SAGE_`` environment variables, and has the same ``SAGE_ROOT`` and
-``SAGE_LOCAL`` (see also :issue:`29446`). If ``SAGE_ROOT`` is a path,
-we normalize it, but keep in mind that ``SAGE_ROOT`` may also be
-``None``::
-
-    sage: env = {k:v for (k,v) in os.environ.items() if not k.startswith("SAGE_")}
-    sage: from subprocess import check_output
-    sage: module_name = "sage.all"   # hide .all import from the linter
-    sage: cmd  = f"from {module_name} import SAGE_ROOT, SAGE_LOCAL;"
-    sage: cmd +=  "from os.path import samefile;"
-    sage: if SAGE_ROOT is None:
-    ....:     cmd +=  "s1 = SAGE_ROOT is None;"
-    ....: else:
-    ....:     cmd += f"s1 = samefile(SAGE_ROOT, '{SAGE_ROOT}');"
-    sage: cmd += f"s2 = samefile(SAGE_LOCAL, '{SAGE_LOCAL}');"
-    sage: cmd += "print(s1 and s2);"
-    sage: out = check_output([sys.executable, "-c", cmd], env=env).decode().strip()   # long time
-    sage: out == "True"                                                               # long time
-    True
-
 AUTHORS:
 
 - \R. Andrew Ohana (2012): initial version
@@ -48,7 +26,9 @@ from typing import Optional
 
 from platformdirs import site_data_dir, user_data_dir
 
+import sage.config
 from sage import version
+from sage.config import get_include_dirs
 
 # All variables set by var() appear in this SAGE_ENV dict
 SAGE_ENV = dict()
@@ -149,15 +129,7 @@ def var(key: str, *fallbacks: Optional[str], force: bool = False) -> Optional[st
     else:
         value = os.environ.get(key)
     if value is None:
-        try:
-            import sage_conf
-            value = getattr(sage_conf, key, None)
-        except ImportError:
-            try:
-                import sage.config
-                value = getattr(sage.config, key, None)
-            except ImportError:
-                pass
+        value = getattr(sage.config, key, None)
 
     # Try all fallbacks in order as long as we don't have a non-empty value
     for f in fallbacks:
@@ -307,6 +279,9 @@ def sage_include_directories(use_sources=False):
 
         sage: import sage.env
         sage: sage.env.sage_include_directories()
+        doctest:warning...
+        DeprecationWarning: use sage.config.get_include_dirs() instead
+        ...
         ['...',
          '.../numpy/...core/include',
          '.../include/python...']
@@ -327,6 +302,9 @@ def sage_include_directories(use_sources=False):
         sage: any(os.path.isfile(os.path.join(d, file)) for d in dirs)
         True
     """
+    from sage.misc.superseded import deprecation
+    deprecation(40765, 'use sage.config.get_include_dirs() instead')
+
     if use_sources:
         dirs = [SAGE_SRC]
     else:
@@ -341,6 +319,8 @@ def sage_include_directories(use_sources=False):
 
     dirs.append(sysconfig.get_config_var('INCLUDEPY'))
 
+    dirs.extend([dir.as_posix() for dir in get_include_dirs()])
+
     return dirs
 
 
@@ -515,7 +495,7 @@ def cython_aliases(required_modules=None, optional_modules=None):
     return aliases
 
 
-def sage_data_paths(name: str | None) -> set[str]:
+def sage_data_paths(name: str = '') -> set[str]:
     r"""
     Search paths for general data files.
 
@@ -536,11 +516,9 @@ def sage_data_paths(name: str | None) -> set[str]:
         }
         paths.add(user_data_dir("sagemath"))
         paths.add(user_data_dir())
-        paths.add(site_data_dir("sagemath"))
-        paths.add(site_data_dir())
+        for path in site_data_dir("sagemath", multipath=True).split(os.pathsep) + site_data_dir(multipath=True).split(os.pathsep):
+            paths.add(path)
     else:
-        paths = {path for path in SAGE_DATA_PATH.split(os.pathsep)}
+        paths = set(SAGE_DATA_PATH.split(os.pathsep))
 
-    if name is None:
-        return {path for path in paths if path}
-    return {os.path.join(path, name) for path in paths if path}
+    return {os.path.join(path, name) for path in paths if os.path.exists(path)}
