@@ -103,9 +103,7 @@ class LinearExpression(ModuleElement):
         """
         Return the coefficient vector.
 
-        OUTPUT:
-
-        The coefficient vector of the linear expression.
+        OUTPUT: the coefficient vector of the linear expression
 
         EXAMPLES::
 
@@ -124,9 +122,7 @@ class LinearExpression(ModuleElement):
         """
         Return the constant term.
 
-        OUTPUT:
-
-        The constant term of the linear expression.
+        OUTPUT: the constant term of the linear expression
 
         EXAMPLES::
 
@@ -225,12 +221,10 @@ class LinearExpression(ModuleElement):
         - ``include_constant`` -- whether to include the constant
           term
 
-        - ``multiplication`` -- string (default: ``*``); the
+        - ``multiplication`` -- string (default: ``'*'``); the
           multiplication symbol to use
 
-        OUTPUT:
-
-        A string.
+        OUTPUT: string
 
         EXAMPLES::
 
@@ -359,9 +353,7 @@ class LinearExpression(ModuleElement):
 
         - ``base_ring`` -- a ring; the new base ring
 
-        OUTPUT:
-
-        A new linear expression over the new base ring.
+        OUTPUT: a new linear expression over the new base ring
 
         EXAMPLES::
 
@@ -427,9 +419,7 @@ class LinearExpression(ModuleElement):
         - ``point`` -- list/tuple/iterable of coordinates; the
           coordinates of a point
 
-        OUTPUT:
-
-        The linear expression `Ax + b` evaluated at the point `x`.
+        OUTPUT: the linear expression `Ax + b` evaluated at the point `x`
 
         EXAMPLES::
 
@@ -510,7 +500,7 @@ class LinearExpressionModule(Parent, UniqueRepresentation):
         """
         from sage.sets.family import Family
         gens = self.gens()
-        d = {i: g for i, g in enumerate(gens)}
+        d = dict(enumerate(gens))
         d['b'] = self.element_class(self, self.ambient_module().zero(),
                                     self.base_ring().one())
         return Family(list(range(len(gens))) + ['b'], lambda i: d[i])
@@ -520,9 +510,7 @@ class LinearExpressionModule(Parent, UniqueRepresentation):
         """
         Return the number of linear variables.
 
-        OUTPUT:
-
-        An integer.
+        OUTPUT: integer
 
         EXAMPLES::
 
@@ -538,9 +526,7 @@ class LinearExpressionModule(Parent, UniqueRepresentation):
         """
         Return the generators of ``self``.
 
-        OUTPUT:
-
-        A tuple of linear expressions, one for each linear variable.
+        OUTPUT: a tuple of linear expressions, one for each linear variable
 
         EXAMPLES::
 
@@ -561,9 +547,7 @@ class LinearExpressionModule(Parent, UniqueRepresentation):
 
         - ``i`` -- integer
 
-        OUTPUT:
-
-        A linear expression.
+        OUTPUT: a linear expression
 
         EXAMPLES::
 
@@ -752,9 +736,7 @@ class LinearExpressionModule(Parent, UniqueRepresentation):
         """
         Return a string representation.
 
-        OUTPUT:
-
-        A string.
+        OUTPUT: string
 
         EXAMPLES::
 
@@ -773,9 +755,7 @@ class LinearExpressionModule(Parent, UniqueRepresentation):
 
         - ``base_ring`` -- a ring; the new base ring
 
-        OUTPUT:
-
-        A new linear expression over the new base ring.
+        OUTPUT: a new linear expression over the new base ring
 
         EXAMPLES::
 
