@@ -47,7 +47,8 @@ def _all_cycles_iterator_vertex(self, vertex, starting_vertices=None, simple=Fal
 
     - ``simple`` -- boolean (default: ``False``); if set to ``True``, then
       only simple cycles are considered. A cycle is simple if the only
-      vertex occurring twice in it is the starting and ending one.
+      vertex occurring twice in it is the starting and ending one and no edge
+      occurs twice.
 
     - ``rooted`` -- boolean (default: ``False``); if set to False, then
       cycles differing only by their starting vertex are considered the same
@@ -62,8 +63,8 @@ def _all_cycles_iterator_vertex(self, vertex, starting_vertices=None, simple=Fal
       the empty paths are also enumerated
 
     - ``remove_acyclic_edges`` -- boolean (default: ``True``); whether
-      acyclic edges must be removed from the graph.  Used to avoid
-      recomputing it for each vertex
+      acyclic edges must be removed from the graph if ``self`` is directed.
+      Used to avoid recomputing it for each vertex
 
     - ``weight_function`` -- function (default: ``None``); a function that
       takes as input an edge ``(u, v, l)`` and outputs its weight. If not
@@ -154,6 +155,23 @@ def _all_cycles_iterator_vertex(self, vertex, starting_vertices=None, simple=Fal
         Traceback (most recent call last):
         ...
         ValueError: negative weight is not allowed
+
+    The function works for an undirected graph. Specifically, each cycle is
+    enumerated exactly once, meaning a cycle and its reverse are not listed separately::
+
+        sage: g = Graph({0: [1, 2], 1: [0, 2], 2: [0, 1]})
+        sage: it = g._all_cycles_iterator_vertex(0, simple=False)
+        sage: for i in range(7): print(next(it))
+        [0, 1, 0]
+        [0, 2, 0]
+        [0, 1, 2, 0]
+        [0, 1, 0, 1, 0]
+        [0, 1, 0, 2, 0]
+        [0, 1, 2, 1, 0]
+        [0, 2, 0, 2, 0]
+        sage: for cycle in g._all_cycles_iterator_vertex(0, simple=True):
+        ....:     print(cycle)
+        [0, 1, 2, 0]
     """
     if starting_vertices is None:
         starting_vertices = [vertex]
@@ -164,7 +182,7 @@ def _all_cycles_iterator_vertex(self, vertex, starting_vertices=None, simple=Fal
         else:
             yield [vertex]
     # First we remove vertices and edges that are not part of any cycle
-    if remove_acyclic_edges:
+    if self.is_directed() and remove_acyclic_edges:
         sccs = self.strongly_connected_components()
         if len(sccs) == 1:
             h = self
@@ -177,6 +195,8 @@ def _all_cycles_iterator_vertex(self, vertex, starting_vertices=None, simple=Fal
             h.delete_edges((u, v) for u, v in h.edge_iterator(labels=False) if d[u] != d[v])
     else:
         h = self
+        int_to_vertex = list(h)
+        vertex_to_int = {v: i for i, v in enumerate(int_to_vertex)}
 
     by_weight, weight_function = self._get_weight_function(by_weight=by_weight,
                                                            weight_function=weight_function,
@@ -195,15 +215,28 @@ def _all_cycles_iterator_vertex(self, vertex, starting_vertices=None, simple=Fal
         length, path = heappop(heap_queue)
         # Checks if a cycle has been found
         if len(path) > 1 and path[0] == path[-1]:
-            if report_weight:
-                yield (length, path)
-            else:
-                yield path
+            report = True
+            if not self.is_directed():
+                if simple:
+                    report = len(path) > 3 and vertex_to_int[path[1]] < vertex_to_int[path[-2]]
+                else:
+                    L = len(path)
+                    for i in range(1, L // 2):
+                        if vertex_to_int[path[i]] > vertex_to_int[path[L - i - 1]]:
+                            report = False
+                            break
+                        if vertex_to_int[path[i]] < vertex_to_int[path[L - i - 1]]:
+                            break
+            if report:
+                if report_weight:
+                    yield (length, path)
+                else:
+                    yield path
         # If simple is set to True, only simple cycles are
         # allowed, Then it discards the current path
         if (not simple or path.count(path[-1]) == 1):
-            for e in h.outgoing_edge_iterator(path[-1]):
-                neighbor = e[1]
+            for e in h.edge_iterator(vertices=[path[-1]]):
+                neighbor = e[1] if e[0] == path[-1] else e[0]
                 # Makes sure that the current cycle is not too long.
                 # If cycles are not rooted, makes sure to keep only the
                 # minimum cycle according to the lexicographic order
@@ -265,21 +298,21 @@ def _all_simple_cycles_iterator_edge(self, edge, max_length=None,
         sage: g = graphs.Grid2dGraph(2, 5).to_directed()
         sage: it = g._all_simple_cycles_iterator_edge(((0, 0), (0, 1), None), report_weight=True)
         sage: for i in range(5): print(next(it))
-        (2, [(0, 0), (0, 1), (0, 0)])
-        (4, [(0, 0), (0, 1), (1, 1), (1, 0), (0, 0)])
-        (6, [(0, 0), (0, 1), (0, 2), (1, 2), (1, 1), (1, 0), (0, 0)])
-        (8, [(0, 0), (0, 1), (0, 2), (0, 3), (1, 3), (1, 2), (1, 1), (1, 0), (0, 0)])
-        (10, [(0, 0), (0, 1), (0, 2), (0, 3), (0, 4), (1, 4), (1, 3), (1, 2), (1, 1), (1, 0), (0, 0)])
+        (2.0, [(0, 0), (0, 1), (0, 0)])
+        (4.0, [(0, 0), (0, 1), (1, 1), (1, 0), (0, 0)])
+        (6.0, [(0, 0), (0, 1), (0, 2), (1, 2), (1, 1), (1, 0), (0, 0)])
+        (8.0, [(0, 0), (0, 1), (0, 2), (0, 3), (1, 3), (1, 2), (1, 1), (1, 0), (0, 0)])
+        (10.0, [(0, 0), (0, 1), (0, 2), (0, 3), (0, 4), (1, 4), (1, 3), (1, 2), (1, 1), (1, 0), (0, 0)])
 
     The function works for undirected graphs as well::
 
         sage: g = graphs.Grid2dGraph(2, 5)
         sage: it = g._all_simple_cycles_iterator_edge(((0, 0), (0, 1), None), report_weight=True)
         sage: for i in range(4): print(next(it))
-        (4, [(0, 0), (0, 1), (1, 1), (1, 0), (0, 0)])
-        (6, [(0, 0), (0, 1), (0, 2), (1, 2), (1, 1), (1, 0), (0, 0)])
-        (8, [(0, 0), (0, 1), (0, 2), (0, 3), (1, 3), (1, 2), (1, 1), (1, 0), (0, 0)])
-        (10, [(0, 0), (0, 1), (0, 2), (0, 3), (0, 4), (1, 4), (1, 3), (1, 2), (1, 1), (1, 0), (0, 0)])
+        (4.0, [(0, 0), (0, 1), (1, 1), (1, 0), (0, 0)])
+        (6.0, [(0, 0), (0, 1), (0, 2), (1, 2), (1, 1), (1, 0), (0, 0)])
+        (8.0, [(0, 0), (0, 1), (0, 2), (0, 3), (1, 3), (1, 2), (1, 1), (1, 0), (0, 0)])
+        (10.0, [(0, 0), (0, 1), (0, 2), (0, 3), (0, 4), (1, 4), (1, 3), (1, 2), (1, 1), (1, 0), (0, 0)])
 
     Each edge must have a positive weight::
 
@@ -346,7 +379,6 @@ def _all_simple_cycles_iterator_edge(self, edge, max_length=None,
                                  weight_function=weight_function,
                                  by_weight=by_weight,
                                  check_weight=check_weight,
-                                 algorithm=('Feng' if h.is_directed() else 'Yen'),
                                  report_edges=False,
                                  report_weight=True)
 
@@ -374,7 +406,11 @@ def all_cycles_iterator(self, starting_vertices=None, simple=False,
     Return an iterator over all the cycles of ``self`` starting with one of
     the given vertices. Each edge must have a positive weight.
 
-    The cycles are enumerated in increasing length order.
+    The cycles are enumerated in increasing length order. Here, a cycle
+    means a closed walk `v_0e_0v_1e_1 \ldots v_{k-1}e_{k-1}v_0` where
+    `v_i` are vertices and `e_i` are edges. `v_i` and `e_i`
+    (`0 \leq i < k`) may not be distinct. If ``simple=True``, then cycles
+    with distinct `v_i` and `e_i` (`0 \leq i < k`) are enumerated.
 
     INPUT:
 
@@ -385,7 +421,8 @@ def all_cycles_iterator(self, starting_vertices=None, simple=False,
 
     - ``simple`` -- boolean (default: ``False``); if set to ``True``, then
       only simple cycles are considered. A cycle is simple if the only
-      vertex occurring twice in it is the starting and ending one.
+      vertex occurring twice in it is the starting and ending one and no edge
+      occurs twice.
 
     - ``rooted`` -- boolean (default: ``False``); if set to False, then
       cycles differing only by their starting vertex are considered the same
@@ -423,7 +460,8 @@ def all_cycles_iterator(self, starting_vertices=None, simple=False,
 
         - The algorithm ``'B'`` holds cycle iterators starting with each edge,
           and output them in increasing length order. It depends on the k-shortest
-          simple paths algorithm. Thus, it is not available if ``simple=False``.
+          simple paths algorithm. Thus, it is not available if ``simple=False`` or
+          ``rooted=True`` or ``starting_vertices`` is not ``None``.
 
     OUTPUT: iterator
 
@@ -535,7 +573,8 @@ def all_cycles_iterator(self, starting_vertices=None, simple=False,
         [0, 1, 2, 0]
         [2, 3, 4, 5, 2]
 
-    The algorithm ``'B'`` is available only when `simple=True`::
+    The algorithm ``'B'`` is unavailable when ``simple=False`` or ``rooted=True``
+    or ``starting_vertices is not None``::
 
         sage: g = DiGraph()
         sage: g.add_edges([('a', 'b', 1), ('b', 'a', 1)])
@@ -543,24 +582,35 @@ def all_cycles_iterator(self, starting_vertices=None, simple=False,
         ....:
         Traceback (most recent call last):
         ...
-        ValueError: The algorithm 'B' is available only when simple=True.
-
-    The algorithm ``'A'`` is available only for directed graphs::
-
-        sage: g = Graph({0: [1, 2], 1: [0, 2], 2: [0, 1]})
-        sage: next(g.all_cycles_iterator(algorithm='A', simple=True))
+        ValueError: The algorithm 'B' is unavailable when simple=False.
+        sage: next(g.all_cycles_iterator(algorithm='B', simple=True, rooted=True))
         Traceback (most recent call last):
         ...
-        ValueError: The algorithm 'A' is available only for directed graphs.
+        ValueError: The algorithm 'B' is unavailable when rooted=True.
+        sage: next(g.all_cycles_iterator(algorithm='B', simple=True, starting_vertices=['a']))
+        Traceback (most recent call last):
+        ...
+        ValueError: The algorithm 'B' is unavailable when starting_vertices is not None.
+
+    The algorithm ``'A'`` works for undirected graphs as well. Specifically, each cycle is
+    enumerated exactly once, meaning a cycle and its reverse are not listed separately::
+
+        sage: g = Graph({0: [1, 2], 1: [0, 2], 2: [0, 1]})
+        sage: for cycle in g.all_cycles_iterator(algorithm='A', simple=True):
+        ....:     print(cycle)
+        [0, 1, 2, 0]
     """
+    if algorithm == 'B':
+        if not simple:
+            raise ValueError("The algorithm 'B' is unavailable when simple=False.")
+        if starting_vertices:
+            raise ValueError("The algorithm 'B' is unavailable when starting_vertices is not None.")
+        if rooted:
+            raise ValueError("The algorithm 'B' is unavailable when rooted=True.")
+
     if starting_vertices is None:
         starting_vertices = self
 
-    if algorithm == 'A' and not self.is_directed():
-        raise ValueError("The algorithm 'A' is available only for directed graphs.")
-    if algorithm == 'B' and not simple:
-        raise ValueError("The algorithm 'B' is available only when simple=True.")
-
     by_weight, weight_function = self._get_weight_function(by_weight=by_weight,
                                                            weight_function=weight_function,
                                                            check_weight=check_weight)
@@ -664,7 +714,7 @@ def all_simple_cycles(self, starting_vertices=None, rooted=False,
                       max_length=None, trivial=False,
                       weight_function=None, by_weight=False,
                       check_weight=True, report_weight=False,
-                      algorithm='A'):
+                      algorithm='B'):
     r"""
     Return a list of all simple cycles of ``self``. The cycles are
     enumerated in increasing length order. Each edge must have a
@@ -705,7 +755,7 @@ def all_simple_cycles(self, starting_vertices=None, rooted=False,
       a cycle is returned. Otherwise a tuple of cycle length and cycle is
       returned.
 
-    - ``algorithm`` -- string (default: ``'A'``); the algorithm used to
+    - ``algorithm`` -- string (default: ``'B'``); the algorithm used to
       enumerate the cycles.
 
         - The algorithm ``'A'`` holds cycle iterators starting with each vertex,
@@ -737,20 +787,20 @@ def all_simple_cycles(self, starting_vertices=None, rooted=False,
         sage: g.all_simple_cycles(max_length=6)
         [[0, 1, 0], [0, 4, 0], [0, 5, 0], [1, 2, 1], [1, 6, 1], [2, 3, 2],
          [2, 7, 2], [3, 4, 3], [3, 8, 3], [4, 9, 4], [5, 7, 5], [5, 8, 5],
-         [6, 8, 6], [6, 9, 6], [7, 9, 7], [0, 1, 2, 3, 4, 0],
-         [0, 1, 2, 7, 5, 0], [0, 1, 6, 8, 5, 0], [0, 1, 6, 9, 4, 0],
-         [0, 4, 3, 2, 1, 0], [0, 4, 3, 8, 5, 0], [0, 4, 9, 6, 1, 0],
-         [0, 4, 9, 7, 5, 0], [0, 5, 7, 2, 1, 0], [0, 5, 7, 9, 4, 0],
-         [0, 5, 8, 3, 4, 0], [0, 5, 8, 6, 1, 0], [1, 2, 3, 8, 6, 1],
-         [1, 2, 7, 9, 6, 1], [1, 6, 8, 3, 2, 1], [1, 6, 9, 7, 2, 1],
-         [2, 3, 4, 9, 7, 2], [2, 3, 8, 5, 7, 2], [2, 7, 5, 8, 3, 2],
-         [2, 7, 9, 4, 3, 2], [3, 4, 9, 6, 8, 3], [3, 8, 6, 9, 4, 3],
+         [6, 8, 6], [6, 9, 6], [7, 9, 7], [0, 1, 6, 8, 5, 0],
+         [0, 1, 6, 9, 4, 0], [0, 1, 2, 7, 5, 0], [0, 1, 2, 3, 4, 0],
+         [0, 4, 9, 7, 5, 0], [0, 4, 9, 6, 1, 0], [0, 4, 3, 8, 5, 0],
+         [0, 4, 3, 2, 1, 0], [0, 5, 8, 6, 1, 0], [0, 5, 8, 3, 4, 0],
+         [0, 5, 7, 2, 1, 0], [0, 5, 7, 9, 4, 0], [1, 2, 7, 9, 6, 1],
+         [1, 2, 3, 8, 6, 1], [1, 6, 9, 7, 2, 1], [1, 6, 8, 3, 2, 1],
+         [2, 3, 8, 5, 7, 2], [2, 3, 4, 9, 7, 2], [2, 7, 9, 4, 3, 2],
+         [2, 7, 5, 8, 3, 2], [3, 4, 9, 6, 8, 3], [3, 8, 6, 9, 4, 3],
          [5, 7, 9, 6, 8, 5], [5, 8, 6, 9, 7, 5], [0, 1, 2, 3, 8, 5, 0],
-         [0, 1, 2, 7, 9, 4, 0], [0, 1, 6, 8, 3, 4, 0],
-         [0, 1, 6, 9, 7, 5, 0], [0, 4, 3, 2, 7, 5, 0],
+         [0, 1, 2, 7, 9, 4, 0], [0, 1, 6, 9, 7, 5, 0],
+         [0, 1, 6, 8, 3, 4, 0], [0, 4, 3, 2, 7, 5, 0],
          [0, 4, 3, 8, 6, 1, 0], [0, 4, 9, 6, 8, 5, 0],
-         [0, 4, 9, 7, 2, 1, 0], [0, 5, 7, 2, 3, 4, 0],
-         [0, 5, 7, 9, 6, 1, 0], [0, 5, 8, 3, 2, 1, 0],
+         [0, 4, 9, 7, 2, 1, 0], [0, 5, 7, 9, 6, 1, 0],
+         [0, 5, 7, 2, 3, 4, 0], [0, 5, 8, 3, 2, 1, 0],
          [0, 5, 8, 6, 9, 4, 0], [1, 2, 3, 4, 9, 6, 1],
          [1, 2, 7, 5, 8, 6, 1], [1, 6, 8, 5, 7, 2, 1],
          [1, 6, 9, 4, 3, 2, 1], [2, 3, 8, 6, 9, 7, 2],
@@ -762,8 +812,8 @@ def all_simple_cycles(self, starting_vertices=None, rooted=False,
         sage: g = graphs.CompleteGraph(4).to_directed()
         sage: g.all_simple_cycles()
         [[0, 1, 0], [0, 2, 0], [0, 3, 0], [1, 2, 1], [1, 3, 1], [2, 3, 2],
-         [0, 1, 2, 0], [0, 1, 3, 0], [0, 2, 1, 0], [0, 2, 3, 0],
-         [0, 3, 1, 0], [0, 3, 2, 0], [1, 2, 3, 1], [1, 3, 2, 1],
+         [0, 1, 3, 0], [0, 1, 2, 0], [0, 2, 3, 0], [0, 2, 1, 0],
+         [0, 3, 2, 0], [0, 3, 1, 0], [1, 2, 3, 1], [1, 3, 2, 1],
          [0, 1, 2, 3, 0], [0, 1, 3, 2, 0], [0, 2, 1, 3, 0],
          [0, 2, 3, 1, 0], [0, 3, 1, 2, 0], [0, 3, 2, 1, 0]]
 
@@ -774,41 +824,39 @@ def all_simple_cycles(self, starting_vertices=None, rooted=False,
         sage: g = graphs.CompleteGraph(20).to_directed()
         sage: g.all_simple_cycles(max_length=2)
         [[0, 1, 0], [0, 2, 0], [0, 3, 0], [0, 4, 0], [0, 5, 0], [0, 6, 0], [0, 7, 0],
-         [0, 8, 0], [0, 9, 0], [0, 10, 0], [0, 11, 0], [0, 12, 0], [0, 13, 0],
-         [0, 14, 0], [0, 15, 0], [0, 16, 0], [0, 17, 0], [0, 18, 0], [0, 19, 0],
-         [1, 2, 1], [1, 3, 1], [1, 4, 1], [1, 5, 1], [1, 6, 1], [1, 7, 1], [1, 8, 1],
-         [1, 9, 1], [1, 10, 1], [1, 11, 1], [1, 12, 1], [1, 13, 1], [1, 14, 1],
-         [1, 15, 1], [1, 16, 1], [1, 17, 1], [1, 18, 1], [1, 19, 1], [2, 3, 2],
-         [2, 4, 2], [2, 5, 2], [2, 6, 2], [2, 7, 2], [2, 8, 2], [2, 9, 2], [2, 10, 2],
-         [2, 11, 2], [2, 12, 2], [2, 13, 2], [2, 14, 2], [2, 15, 2], [2, 16, 2],
-         [2, 17, 2], [2, 18, 2], [2, 19, 2], [3, 4, 3], [3, 5, 3], [3, 6, 3],
-         [3, 7, 3], [3, 8, 3], [3, 9, 3], [3, 10, 3], [3, 11, 3], [3, 12, 3],
-         [3, 13, 3], [3, 14, 3], [3, 15, 3], [3, 16, 3], [3, 17, 3], [3, 18, 3],
-         [3, 19, 3], [4, 5, 4], [4, 6, 4], [4, 7, 4], [4, 8, 4], [4, 9, 4], [4, 10, 4],
-         [4, 11, 4], [4, 12, 4], [4, 13, 4], [4, 14, 4], [4, 15, 4], [4, 16, 4],
-         [4, 17, 4], [4, 18, 4], [4, 19, 4], [5, 6, 5], [5, 7, 5], [5, 8, 5],
-         [5, 9, 5], [5, 10, 5], [5, 11, 5], [5, 12, 5], [5, 13, 5], [5, 14, 5],
-         [5, 15, 5], [5, 16, 5], [5, 17, 5], [5, 18, 5], [5, 19, 5], [6, 7, 6],
-         [6, 8, 6], [6, 9, 6], [6, 10, 6], [6, 11, 6], [6, 12, 6], [6, 13, 6],
-         [6, 14, 6], [6, 15, 6], [6, 16, 6], [6, 17, 6], [6, 18, 6], [6, 19, 6],
-         [7, 8, 7], [7, 9, 7], [7, 10, 7], [7, 11, 7], [7, 12, 7], [7, 13, 7],
-         [7, 14, 7], [7, 15, 7], [7, 16, 7], [7, 17, 7], [7, 18, 7], [7, 19, 7],
-         [8, 9, 8], [8, 10, 8], [8, 11, 8], [8, 12, 8], [8, 13, 8], [8, 14, 8],
-         [8, 15, 8], [8, 16, 8], [8, 17, 8], [8, 18, 8], [8, 19, 8], [9, 10, 9],
-         [9, 11, 9], [9, 12, 9], [9, 13, 9], [9, 14, 9], [9, 15, 9], [9, 16, 9],
-         [9, 17, 9], [9, 18, 9], [9, 19, 9], [10, 11, 10], [10, 12, 10], [10, 13, 10],
-         [10, 14, 10], [10, 15, 10], [10, 16, 10], [10, 17, 10], [10, 18, 10],
-         [10, 19, 10], [11, 12, 11], [11, 13, 11], [11, 14, 11], [11, 15, 11],
-         [11, 16, 11], [11, 17, 11], [11, 18, 11], [11, 19, 11], [12, 13, 12],
-         [12, 14, 12], [12, 15, 12], [12, 16, 12], [12, 17, 12], [12, 18, 12],
-         [12, 19, 12], [13, 14, 13], [13, 15, 13], [13, 16, 13], [13, 17, 13],
-         [13, 18, 13], [13, 19, 13], [14, 15, 14], [14, 16, 14], [14, 17, 14],
-         [14, 18, 14], [14, 19, 14], [15, 16, 15], [15, 17, 15], [15, 18, 15],
-         [15, 19, 15], [16, 17, 16], [16, 18, 16], [16, 19, 16], [17, 18, 17],
-         [17, 19, 17], [18, 19, 18]]
+         [0, 8, 0], [0, 9, 0], [0, 10, 0], [0, 11, 0], [0, 12, 0], [0, 13, 0], [0, 14, 0],
+         [0, 15, 0], [0, 16, 0], [0, 17, 0], [0, 18, 0], [0, 19, 0], [1, 2, 1], [1, 3, 1],
+         [1, 4, 1], [1, 5, 1], [1, 6, 1], [1, 7, 1], [1, 8, 1], [1, 9, 1], [2, 3, 2],
+         [2, 4, 2], [2, 5, 2], [2, 6, 2], [2, 7, 2], [2, 8, 2], [2, 9, 2], [3, 4, 3],
+         [3, 5, 3], [3, 6, 3], [3, 7, 3], [3, 8, 3], [3, 9, 3], [4, 5, 4], [4, 6, 4],
+         [4, 7, 4], [4, 8, 4], [4, 9, 4], [5, 6, 5], [5, 7, 5], [5, 8, 5], [5, 9, 5],
+         [6, 7, 6], [6, 8, 6], [6, 9, 6], [7, 8, 7], [7, 9, 7], [8, 9, 8], [10, 1, 10],
+         [10, 2, 10], [10, 3, 10], [10, 4, 10], [10, 5, 10], [10, 6, 10], [10, 7, 10],
+         [10, 8, 10], [10, 9, 10], [11, 1, 11], [11, 2, 11], [11, 3, 11], [11, 4, 11],
+         [11, 5, 11], [11, 6, 11], [11, 7, 11], [11, 8, 11], [11, 9, 11], [11, 10, 11],
+         [12, 1, 12], [12, 2, 12], [12, 3, 12], [12, 4, 12], [12, 5, 12], [12, 6, 12],
+         [12, 7, 12], [12, 8, 12], [12, 9, 12], [12, 10, 12], [12, 11, 12], [13, 1, 13],
+         [13, 2, 13], [13, 3, 13], [13, 4, 13], [13, 5, 13], [13, 6, 13], [13, 7, 13],
+         [13, 8, 13], [13, 9, 13], [13, 10, 13], [13, 11, 13], [13, 12, 13], [14, 1, 14],
+         [14, 2, 14], [14, 3, 14], [14, 4, 14], [14, 5, 14], [14, 6, 14], [14, 7, 14],
+         [14, 8, 14], [14, 9, 14], [14, 10, 14], [14, 11, 14], [14, 12, 14], [14, 13, 14],
+         [15, 1, 15], [15, 2, 15], [15, 3, 15], [15, 4, 15], [15, 5, 15], [15, 6, 15],
+         [15, 7, 15], [15, 8, 15], [15, 9, 15], [15, 10, 15], [15, 11, 15], [15, 12, 15],
+         [15, 13, 15], [15, 14, 15], [16, 1, 16], [16, 2, 16], [16, 3, 16], [16, 4, 16],
+         [16, 5, 16], [16, 6, 16], [16, 7, 16], [16, 8, 16], [16, 9, 16], [16, 10, 16],
+         [16, 11, 16], [16, 12, 16], [16, 13, 16], [16, 14, 16], [16, 15, 16], [17, 1, 17],
+         [17, 2, 17], [17, 3, 17], [17, 4, 17], [17, 5, 17], [17, 6, 17], [17, 7, 17],
+         [17, 8, 17], [17, 9, 17], [17, 10, 17], [17, 11, 17], [17, 12, 17], [17, 13, 17],
+         [17, 14, 17], [17, 15, 17], [17, 16, 17], [18, 1, 18], [18, 2, 18], [18, 3, 18],
+         [18, 4, 18], [18, 5, 18], [18, 6, 18], [18, 7, 18], [18, 8, 18], [18, 9, 18],
+         [18, 10, 18], [18, 11, 18], [18, 12, 18], [18, 13, 18], [18, 14, 18], [18, 15, 18],
+         [18, 16, 18], [18, 17, 18], [19, 1, 19], [19, 2, 19], [19, 3, 19], [19, 4, 19],
+         [19, 5, 19], [19, 6, 19], [19, 7, 19], [19, 8, 19], [19, 9, 19], [19, 10, 19],
+         [19, 11, 19], [19, 12, 19], [19, 13, 19], [19, 14, 19], [19, 15, 19], [19, 16, 19],
+         [19, 17, 19], [19, 18, 19]]
 
         sage: g = graphs.CompleteGraph(20).to_directed()
-        sage: g.all_simple_cycles(max_length=2, starting_vertices=[0])
+        sage: g.all_simple_cycles(max_length=2, starting_vertices=[0], algorithm='A')
         [[0, 1, 0], [0, 2, 0], [0, 3, 0], [0, 4, 0], [0, 5, 0],
          [0, 6, 0], [0, 7, 0], [0, 8, 0], [0, 9, 0], [0, 10, 0],
          [0, 11, 0], [0, 12, 0], [0, 13, 0], [0, 14, 0], [0, 15, 0],
@@ -818,9 +866,9 @@ def all_simple_cycles(self, starting_vertices=None, rooted=False,
     vertices (compare the following examples)::
 
         sage: g = graphs.CompleteGraph(4).to_directed()
-        sage: g.all_simple_cycles(max_length=2, rooted=False)
+        sage: g.all_simple_cycles(max_length=2, rooted=False, algorithm='A')
         [[0, 1, 0], [0, 2, 0], [0, 3, 0], [1, 2, 1], [1, 3, 1], [2, 3, 2]]
-        sage: g.all_simple_cycles(max_length=2, rooted=True)
+        sage: g.all_simple_cycles(max_length=2, rooted=True, algorithm='A')
         [[0, 1, 0], [0, 2, 0], [0, 3, 0], [1, 0, 1], [1, 2, 1], [1, 3, 1],
          [2, 0, 2], [2, 1, 2], [2, 3, 2], [3, 0, 3], [3, 1, 3], [3, 2, 3]]
 
@@ -829,34 +877,33 @@ def all_simple_cycles(self, starting_vertices=None, rooted=False,
         sage: cycles = g.all_simple_cycles(weight_function=lambda e:e[0]+e[1],
         ....:                              by_weight=True, report_weight=True)
         sage: cycles
-        [(2, [0, 1, 0]), (4, [0, 2, 0]), (6, [0, 1, 2, 0]), (6, [0, 2, 1, 0]),
-         (6, [0, 3, 0]), (6, [1, 2, 1]), (8, [0, 1, 3, 0]), (8, [0, 3, 1, 0]),
-         (8, [1, 3, 1]), (10, [0, 2, 3, 0]), (10, [0, 3, 2, 0]), (10, [2, 3, 2]),
-         (12, [0, 1, 2, 3, 0]), (12, [0, 1, 3, 2, 0]), (12, [0, 2, 1, 3, 0]),
-         (12, [0, 2, 3, 1, 0]), (12, [0, 3, 1, 2, 0]), (12, [0, 3, 2, 1, 0]),
-         (12, [1, 2, 3, 1]), (12, [1, 3, 2, 1])]
+        [(2.0, [0, 1, 0]), (4.0, [0, 2, 0]), (6.0, [0, 1, 2, 0]), (6.0, [0, 2, 1, 0]),
+         (6.0, [0, 3, 0]), (6.0, [1, 2, 1]), (8.0, [0, 1, 3, 0]), (8.0, [0, 3, 1, 0]),
+         (8.0, [1, 3, 1]), (10.0, [0, 2, 3, 0]), (10.0, [0, 3, 2, 0]), (10.0, [2, 3, 2]),
+         (12.0, [0, 1, 3, 2, 0]), (12.0, [0, 1, 2, 3, 0]), (12.0, [0, 2, 3, 1, 0]),
+         (12.0, [0, 2, 1, 3, 0]), (12.0, [0, 3, 2, 1, 0]), (12.0, [0, 3, 1, 2, 0]),
+         (12.0, [1, 2, 3, 1]), (12.0, [1, 3, 2, 1])]
 
     The algorithm ``'B'`` can be used::
 
         sage: cycles_B = g.all_simple_cycles(weight_function=lambda e:e[0]+e[1], by_weight=True,
         ....:                                report_weight=True, algorithm='B')
         sage: cycles_B
-        [(2, [0, 1, 0]), (4, [0, 2, 0]), (6, [0, 1, 2, 0]), (6, [0, 2, 1, 0]),
-         (6, [0, 3, 0]), (6, [1, 2, 1]), (8, [0, 1, 3, 0]), (8, [0, 3, 1, 0]),
-         (8, [1, 3, 1]), (10, [0, 2, 3, 0]), (10, [0, 3, 2, 0]), (10, [2, 3, 2]),
-         (12, [0, 1, 3, 2, 0]), (12, [0, 1, 2, 3, 0]), (12, [0, 2, 3, 1, 0]),
-         (12, [0, 2, 1, 3, 0]), (12, [0, 3, 2, 1, 0]), (12, [0, 3, 1, 2, 0]),
-         (12, [1, 2, 3, 1]), (12, [1, 3, 2, 1])]
+        [(2.0, [0, 1, 0]), (4.0, [0, 2, 0]), (6.0, [0, 1, 2, 0]), (6.0, [0, 2, 1, 0]),
+         (6.0, [0, 3, 0]), (6.0, [1, 2, 1]), (8.0, [0, 1, 3, 0]), (8.0, [0, 3, 1, 0]),
+         (8.0, [1, 3, 1]), (10.0, [0, 2, 3, 0]), (10.0, [0, 3, 2, 0]), (10.0, [2, 3, 2]),
+         (12.0, [0, 1, 3, 2, 0]), (12.0, [0, 1, 2, 3, 0]), (12.0, [0, 2, 3, 1, 0]),
+         (12.0, [0, 2, 1, 3, 0]), (12.0, [0, 3, 2, 1, 0]), (12.0, [0, 3, 1, 2, 0]),
+         (12.0, [1, 2, 3, 1]), (12.0, [1, 3, 2, 1])]
         sage: cycles.sort() == cycles_B.sort()
         True
 
-    The algorithm ``'A'`` is available only for directed graphs::
+    The algorithm ``'A'`` is available for undirected graphs. Specifically, each cycle is
+    enumerated exactly once, meaning a cycle and its reverse are not listed separately::
 
         sage: g = Graph({0: [1, 2], 1: [0, 2], 2: [0, 1]})
         sage: g.all_simple_cycles(algorithm='A')
-        Traceback (most recent call last):
-        ...
-        ValueError: The algorithm 'A' is available only for directed graphs.
+        [[0, 1, 2, 0]]
     """
     return list(self.all_cycles_iterator(starting_vertices=starting_vertices,
                                          simple=True, rooted=rooted,
