@@ -27,7 +27,7 @@ from sage.structure.element import coercion_model
 
 class CellComplexReference:
 
-    def __init__(self, cell_complex, degree, cells=None):
+    def __init__(self, cell_complex, degree, cells=None) -> None:
         """
         Auxiliary base class for chains and cochains.
 
@@ -124,7 +124,8 @@ class Chains(CellComplexReference, CombinatorialFreeModule):
         sage: c.eval(z)
         6
     """
-    def __init__(self, cell_complex, degree, cells=None, base_ring=None):
+    def __init__(self, cell_complex, degree, cells=None,
+                 base_ring=None) -> None:
         """
         EXAMPLES::
 
@@ -264,7 +265,7 @@ class Chains(CellComplexReference, CombinatorialFreeModule):
             )
             return codomain.from_vector(d * self.to_vector())
 
-        def is_cycle(self):
+        def is_cycle(self) -> bool:
             """
             Test whether the chain is a cycle.
 
@@ -288,7 +289,7 @@ class Chains(CellComplexReference, CombinatorialFreeModule):
             """
             return self.to_complex().is_cycle()
 
-        def is_boundary(self):
+        def is_boundary(self) -> bool:
             """
             Test whether the chain is a boundary.
 
@@ -351,7 +352,8 @@ class Cochains(CellComplexReference, CombinatorialFreeModule):
         sage: c.eval(z)
         6
     """
-    def __init__(self, cell_complex, degree, cells=None, base_ring=None):
+    def __init__(self, cell_complex, degree, cells=None,
+                 base_ring=None) -> None:
         """
         EXAMPLES::
 
@@ -493,7 +495,7 @@ class Cochains(CellComplexReference, CombinatorialFreeModule):
             )
             return codomain.from_vector(d * self.to_vector())
 
-        def is_cocycle(self):
+        def is_cocycle(self) -> bool:
             """
             Test whether the cochain is a cocycle.
 
@@ -517,7 +519,7 @@ class Cochains(CellComplexReference, CombinatorialFreeModule):
             """
             return self.to_complex().is_cycle()
 
-        def is_coboundary(self):
+        def is_coboundary(self) -> bool:
             """
             Test whether the cochain is a coboundary.
 
