@@ -83,9 +83,10 @@ class Lisp(Expect):
                         # The capitalized version of this is used for printing.
                         name='Lisp',
 
-                        # This is regexp of the input prompt.  If you can change
-                        # it to be very obfuscated that would be better.   Even
-                        # better is to use sequence numbers.
+                        # This is regexp of the input prompt.  If you
+                        # can change it to be very obfuscated that
+                        # would be better.  Even better is to use
+                        # sequence numbers.
                         prompt='> ',
 
                         # This is the command that starts up your program
@@ -526,24 +527,6 @@ class LispFunction(ExpectFunction):
         return M.help(self._name)
 
 
-def is_LispElement(x):
-    """
-    EXAMPLES::
-
-        sage: from sage.interfaces.lisp import is_LispElement
-        sage: is_LispElement(2)
-        doctest:...: DeprecationWarning: the function is_LispElement is deprecated; use isinstance(x, sage.interfaces.abc.LispElement) instead
-        See https://github.com/sagemath/sage/issues/34804 for details.
-        False
-        sage: is_LispElement(lisp(2))
-        True
-    """
-    from sage.misc.superseded import deprecation
-    deprecation(34804, "the function is_LispElement is deprecated; use isinstance(x, sage.interfaces.abc.LispElement) instead")
-
-    return isinstance(x, LispElement)
-
-
 # An instance
 lisp = Lisp()
 
