@@ -26,7 +26,6 @@ AUTHORS:
 REFERENCES:
 
 - Chap. 15 of [God1968]_
-
 """
 
 #******************************************************************************
@@ -39,15 +38,20 @@ REFERENCES:
 #                  http://www.gnu.org/licenses/
 #******************************************************************************
 
-from sage.structure.unique_representation import UniqueRepresentation
-from sage.structure.parent import Parent
 from sage.categories.groups import Groups
+from sage.manifolds.differentiable.automorphismfield import (
+    AutomorphismField,
+    AutomorphismFieldParal,
+)
+from sage.manifolds.differentiable.vectorfield_module import (
+    VectorFieldFreeModule,
+    VectorFieldModule,
+)
 from sage.misc.cachefunc import cached_method
+from sage.structure.parent import Parent
+from sage.structure.unique_representation import UniqueRepresentation
 from sage.tensor.modules.free_module_linear_group import FreeModuleLinearGroup
-from sage.manifolds.differentiable.vectorfield_module import (VectorFieldModule,
-                                                              VectorFieldFreeModule)
-from sage.manifolds.differentiable.automorphismfield import (AutomorphismField,
-                                                             AutomorphismFieldParal)
+
 
 class AutomorphismFieldGroup(UniqueRepresentation, Parent):
     r"""
@@ -138,7 +142,6 @@ class AutomorphismFieldGroup(UniqueRepresentation, Parent):
         Id = ∂/∂x⊗dx + ∂/∂y⊗dy
         sage: e.display(eV)
         Id = ∂/∂u⊗du + ∂/∂v⊗dv
-
     """
 
     Element = AutomorphismField
@@ -167,7 +170,6 @@ class AutomorphismFieldGroup(UniqueRepresentation, Parent):
         ``_test_elements`` does not pass due to the failure
         of ``_test_pickling`` in
         :class:`sage.manifolds.differentiable.tensorfield.TensorField`.
-
         """
         if not isinstance(vector_field_module, VectorFieldModule):
             raise TypeError("{} is not a module of vector fields".format(
@@ -175,7 +177,6 @@ class AutomorphismFieldGroup(UniqueRepresentation, Parent):
         Parent.__init__(self, category=Groups())
         self._vmodule = vector_field_module
 
-
     #### Parent methods ####
 
     def _element_constructor_(self, comp=[], frame=None, name=None,
@@ -183,9 +184,7 @@ class AutomorphismFieldGroup(UniqueRepresentation, Parent):
         r"""
         Construct a field of tangent-space automorphisms.
 
-        OUTPUT:
-
-        - :class:`~sage.manifolds.differentiable.automorphismfield.AutomorphismField`
+        OUTPUT: :class:`~sage.manifolds.differentiable.automorphismfield.AutomorphismField`
 
         TESTS::
 
@@ -206,7 +205,6 @@ class AutomorphismFieldGroup(UniqueRepresentation, Parent):
              differentiable manifold M
             sage: a.display(c_xy.frame())
             a = (x^2 + 1) ∂/∂x⊗dx + (y^2 + 1) ∂/∂y⊗dy
-
         """
         if hasattr(comp, 'is_trivial_zero'):
             if (comp - 1).is_trivial_zero():
@@ -227,9 +225,7 @@ class AutomorphismFieldGroup(UniqueRepresentation, Parent):
         r"""
         Construct some specific field of tangent-space automorphisms.
 
-        OUTPUT:
-
-        - :class:`~sage.manifolds.differentiable.automorphismfield.AutomorphismField`
+        OUTPUT: :class:`~sage.manifolds.differentiable.automorphismfield.AutomorphismField`
 
         TESTS::
 
@@ -251,7 +247,6 @@ class AutomorphismFieldGroup(UniqueRepresentation, Parent):
             2 ∂/∂u⊗du + 2 ∂/∂v⊗dv
             sage: a == G.an_element()  # indirect doctest
             True
-
         """
         resu = self.element_class(self._vmodule)
         for dom in resu.domain().subsets():
@@ -266,7 +261,6 @@ class AutomorphismFieldGroup(UniqueRepresentation, Parent):
 
     #### End of parent methods ####
 
-
     #### Monoid methods ####
 
     @cached_method
@@ -305,7 +299,6 @@ class AutomorphismFieldGroup(UniqueRepresentation, Parent):
             sage: G.one().restrict(V)[:]
             [1 0]
             [0 1]
-
         """
         # Specific initializations for the field of identity maps:
         resu = self._element_constructor_(name='Id', latex_name=r'\mathrm{Id}')
@@ -338,7 +331,6 @@ class AutomorphismFieldGroup(UniqueRepresentation, Parent):
             sage: G  # indirect doctest
             General linear group of the Module X(M) of vector fields on the
              2-dimensional differentiable manifold M
-
         """
         return "General linear group of the {}".format(self._vmodule)
 
@@ -354,19 +346,16 @@ class AutomorphismFieldGroup(UniqueRepresentation, Parent):
             \mathrm{GL}\left( \mathfrak{X}\left(M\right) \right)
             sage: latex(G)  # indirect doctest
             \mathrm{GL}\left( \mathfrak{X}\left(M\right) \right)
-
         """
         from sage.misc.latex import latex
-        return r"\mathrm{GL}\left("+ latex(self._vmodule)+ r"\right)"
+        return r"\mathrm{GL}\left(" + latex(self._vmodule) + r"\right)"
 
     def base_module(self):
         r"""
         Return the vector-field module of which ``self`` is the general
         linear group.
 
-        OUTPUT:
-
-        - :class:`~sage.manifolds.differentiable.vectorfield_module.VectorFieldModule`
+        OUTPUT: :class:`~sage.manifolds.differentiable.vectorfield_module.VectorFieldModule`
 
         EXAMPLES:
 
@@ -389,7 +378,6 @@ class AutomorphismFieldGroup(UniqueRepresentation, Parent):
              manifold M
             sage: G.base_module() is M.vector_field_module()
             True
-
         """
         return self._vmodule
 
@@ -547,8 +535,7 @@ class AutomorphismFieldParalGroup(FreeModuleLinearGroup):
         Field of tangent-space automorphisms t^(-1) on the 2-dimensional
          differentiable manifold M
         sage: (t1^(-1)).display()
-        t^(-1) = 1/(e^y + 1) ∂/∂x⊗dx - x*y/(x^2 + (x^2 + 1)*e^y + 1) ∂/∂x⊗dy
-         + 1/(x^2 + 1) ∂/∂y⊗dy
+        t^(-1) = 1/(e^y + 1) ∂/∂x⊗dx - x*y/(x^2*(e^y + 1) + e^y + 1) ∂/∂x⊗dy + 1/(x^2 + 1) ∂/∂y⊗dy
 
     Since any automorphism field can be considered as a tensor field of
     type-`(1,1)` on ``M``, there is a coercion map from ``G`` to the
@@ -590,7 +577,6 @@ class AutomorphismFieldParalGroup(FreeModuleLinearGroup):
     TESTS::
 
         sage: TestSuite(G).run()
-
     """
 
     Element = AutomorphismFieldParal
@@ -609,7 +595,6 @@ class AutomorphismFieldParalGroup(FreeModuleLinearGroup):
             General linear group of the Free module X(M) of vector fields on
              the 2-dimensional differentiable manifold M
             sage: TestSuite(G).run()
-
         """
         if not isinstance(vector_field_module, VectorFieldFreeModule):
             raise TypeError("{} is not a free module of vector fields".format(
