@@ -44,16 +44,18 @@ REFERENCES:
 # *****************************************************************************
 
 from __future__ import annotations
-from typing import Optional, Union, TYPE_CHECKING
-from sage.misc.cachefunc import cached_method
-from sage.tensor.modules.free_module_alt_form import FreeModuleAltForm
+
+from typing import TYPE_CHECKING, Optional, Union
+
 from sage.manifolds.differentiable.tensorfield import TensorField
 from sage.manifolds.differentiable.tensorfield_paral import TensorFieldParal
+from sage.misc.cachefunc import cached_method
+from sage.tensor.modules.free_module_alt_form import FreeModuleAltForm
 
 if TYPE_CHECKING:
-    from sage.manifolds.differentiable.vectorfield_module import VectorFieldModule
     from sage.manifolds.differentiable.metric import PseudoRiemannianMetric
     from sage.manifolds.differentiable.symplectic_form import SymplecticForm
+    from sage.manifolds.differentiable.vectorfield_module import VectorFieldModule
 
 
 class DiffForm(TensorField):
@@ -442,8 +444,8 @@ class DiffForm(TensorField):
             True
         """
         from sage.tensor.modules.format_utilities import (
-            format_unop_txt,
             format_unop_latex,
+            format_unop_txt,
         )
 
         vmodule = self._vmodule  # shortcut
@@ -525,8 +527,8 @@ class DiffForm(TensorField):
         """
         if other._tensor_rank == 0:
             return self * other
-        from sage.typeset.unicode_characters import unicode_wedge
         from sage.tensor.modules.format_utilities import is_atomic
+        from sage.typeset.unicode_characters import unicode_wedge
         if self._domain.is_subset(other._domain):
             if not self._ambient_domain.is_subset(other._ambient_domain):
                 raise ValueError("incompatible ambient domains for exterior product")
@@ -762,8 +764,8 @@ class DiffForm(TensorField):
         """
         from sage.functions.other import factorial
         from sage.tensor.modules.format_utilities import (
-            format_unop_txt,
             format_unop_latex,
+            format_unop_txt,
         )
 
         if nondegenerate_tensor is None:
@@ -937,8 +939,9 @@ class DiffForm(TensorField):
                     self_r._restrictions[dom].interior_product(
                                                     qvect_r._restrictions[dom])
         if resu_degree == 0:
-            if not resu._express:  # only the restrictions to subdomains have
-                                   # been initialized
+            if not resu._express:
+                # only the restrictions to subdomains have
+                # been initialized
                 for chart in dom_resu.top_charts():
                     resu._express[chart] = \
                             resu.restrict(chart.domain()).coord_function(chart)
@@ -1438,10 +1441,12 @@ class DiffFormParal(FreeModuleAltForm, TensorFieldParal, DiffForm):
             sage: a.lie_der(v) == v.contract(diff(a)) + diff(a(v)) # long time
             True
         """
-        from sage.tensor.modules.format_utilities import (format_unop_txt,
-                                                          format_unop_latex)
-        from sage.tensor.modules.comp import CompFullyAntiSym
         from sage.manifolds.differentiable.vectorframe import CoordFrame
+        from sage.tensor.modules.comp import CompFullyAntiSym
+        from sage.tensor.modules.format_utilities import (
+            format_unop_latex,
+            format_unop_txt,
+        )
         fmodule = self._fmodule # shortcut
         rname = format_unop_txt('d', self._name)
         rlname = format_unop_latex(r'\mathrm{d}', self._latex_name)
@@ -1466,8 +1471,9 @@ class DiffFormParal(FreeModuleAltForm, TensorFieldParal, DiffForm):
                     break
             if not coord_frames:
                 for chart in dom._atlas:
-                    if chart != dom._def_chart: # the case def_chart is
-                                                # treated above
+                    if chart != dom._def_chart:
+                        # the case def_chart is
+                        # treated above
                         coordf = chart._frame
                         for frame in self._components:
                             if (frame, coordf) in dom._frame_changes:
@@ -1481,9 +1487,9 @@ class DiffFormParal(FreeModuleAltForm, TensorFieldParal, DiffForm):
             chart = frame._chart
             sc = self._components[frame]
             dc = CompFullyAntiSym(fmodule._ring, frame,
-                                  self._tensor_rank+1,
+                                  self._tensor_rank + 1,
                                   start_index=fmodule._sindex,
-                                output_formatter=fmodule._output_formatter)
+                                  output_formatter=fmodule._output_formatter)
             for ind, val in sc._comp.items():
                 for i in fmodule.irange():
                     ind_d = (i,) + ind
