@@ -23,15 +23,13 @@ AUTHORS:
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
 
-from sage.misc.fast_methods import Singleton
 from sage.manifolds.chart import Chart, RealChart
-from sage.manifolds.scalarfield_algebra import ScalarFieldAlgebra
-from sage.manifolds.manifold_homset import TopologicalManifoldHomset
 from sage.manifolds.differentiable.chart import DiffChart, RealDiffChart
-from sage.manifolds.differentiable.scalarfield_algebra import \
-                                                         DiffScalarFieldAlgebra
-from sage.manifolds.differentiable.manifold_homset import \
-                                                   DifferentiableManifoldHomset
+from sage.manifolds.differentiable.manifold_homset import DifferentiableManifoldHomset
+from sage.manifolds.differentiable.scalarfield_algebra import DiffScalarFieldAlgebra
+from sage.manifolds.manifold_homset import TopologicalManifoldHomset
+from sage.manifolds.scalarfield_algebra import ScalarFieldAlgebra
+from sage.misc.fast_methods import Singleton
 
 # This is a slight abuse by making this a Singleton, but there is no
 #    need to have different copies of this object.
