@@ -721,9 +721,7 @@ def integral(x, *args, **kwds):
         real
         sage: f = exp(-x) * sinh(sqrt(x))
         sage: t = integrate(f, x, 0, Infinity); t           # long time
-        1/4*sqrt(pi)*(erf(1) - 1)*e^(1/4)
-         - 1/4*(sqrt(pi)*(erf(1) - 1) - sqrt(pi) + 2*e^(-1) - 2)*e^(1/4)
-         + 1/4*sqrt(pi)*e^(1/4) - 1/2*e^(1/4) + 1/2*e^(-3/4)
+        1/2*sqrt(pi)*e^(1/4)
         sage: t.canonicalize_radical()                      # long time
         1/2*sqrt(pi)*e^(1/4)
         sage: sage.calculus.calculus.maxima('domain: complex')
@@ -932,7 +930,7 @@ def krull_dimension(x):
         0
         sage: ZZ.krull_dimension()
         1
-        sage: ZZ[sqrt(5)].krull_dimension()                                              # needs sage.rings.number_field sage.symbolic
+        sage: ZZ[sqrt(5)].krull_dimension()                                             # needs sage.rings.number_field sage.symbolic
         1
         sage: U.<x,y,z> = PolynomialRing(ZZ, 3); U
         Multivariate Polynomial Ring in x, y, z over Integer Ring
@@ -1780,7 +1778,7 @@ def isqrt(x):
     try:
         return x.isqrt()
     except AttributeError:
-        from sage.functions.all import floor
+        from sage.functions.other import floor
         n = Integer(floor(x))
         return n.isqrt()
 
@@ -1824,7 +1822,7 @@ def squarefree_part(x):
     except AttributeError:
         pass
     from sage.arith.misc import factor
-    from sage.structure.all import parent
+    from sage.structure.element import parent
     F = factor(x)
     n = parent(x)(1)
     for p, e in F:
