@@ -2,8 +2,8 @@
 r"""
 `q`-expansion of `j`-invariant
 """
-from .eis_series import eisenstein_series_qexp
-from .vm_basis import delta_qexp
+from sage.modular.modform.eis_series import eisenstein_series_qexp
+from sage.modular.modform.vm_basis import delta_qexp
 from sage.rings.rational_field import QQ
 
 
