@@ -31,18 +31,15 @@ different types.  The hierarchy is as follows:
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
 
-import sage.modular.modsym.p1list as p1list
-import sage.modular.modsym.g1list as g1list
-import sage.modular.modsym.ghlist as ghlist
+from sage.categories.finite_enumerated_sets import FiniteEnumeratedSets
+from sage.misc.cachefunc import cached_method
+from sage.misc.persist import register_unpickle_override
+from sage.modular.modsym import g1list, ghlist, p1list
+from sage.modular.modsym.apply import apply_to_monomial
+from sage.modular.modsym.manin_symbol import ManinSymbol
 from sage.rings.integer import Integer
 from sage.structure.parent import Parent
-from sage.misc.persist import register_unpickle_override
-from sage.structure.richcmp import richcmp_method, richcmp
-from sage.categories.finite_enumerated_sets import FiniteEnumeratedSets
-
-from .apply import apply_to_monomial
-
-from sage.modular.modsym.manin_symbol import ManinSymbol
+from sage.structure.richcmp import richcmp, richcmp_method
 
 
 @richcmp_method
@@ -165,7 +162,7 @@ class ManinSymbolList(Parent):
 
     def _apply_S_only_0pm1(self) -> bool:
         """
-        Return True if the coefficient when applying the S relation is
+        Return ``True`` if the coefficient when applying the S relation is
         always 0, 1, or -1.  This is useful for optimizing code in
         relation_matrix.py.
 
@@ -283,6 +280,7 @@ class ManinSymbolList(Parent):
         except KeyError:
             return -1
 
+    @cached_method
     def manin_symbol_list(self):
         """
         Return all the Manin symbols in ``self`` as a list.
@@ -311,15 +309,8 @@ class ManinSymbolList(Parent):
             ...
             [X^2,(3,1)],
             [X^2,(3,2)]]
-
         """
-        import copy
-        try:
-            return copy.copy(self.__manin_symbol_list)
-        except AttributeError:
-            self.__manin_symbol_list = [self.manin_symbol(i)
-                                        for i in range(len(self))]
-        return copy.copy(self.__manin_symbol_list)
+        return [self.manin_symbol(i) for i in range(len(self))]
 
     list = manin_symbol_list
 
@@ -329,11 +320,11 @@ class ManinSymbolList(Parent):
 
         INPUT:
 
-        - ``i`` -- integer, a valid index of a symbol in this list
+        - ``i`` -- integer; a valid index of a symbol in this list
 
         OUTPUT:
 
-        :class:`ManinSymbol` -- the `i`'th Manin symbol in the list.
+        :class:`ManinSymbol` -- the `i`-th Manin symbol in the list.
 
         EXAMPLES::
 
@@ -363,7 +354,6 @@ class ManinSymbolList(Parent):
             sage: from sage.modular.modsym.manin_symbol_list import ManinSymbolList
             sage: m = ManinSymbolList(6,P1List(11))
             sage: m.normalize((0,6,7)) # not implemented in base class
-
         """
         raise NotImplementedError("Only implemented in derived classes")
 
@@ -371,9 +361,7 @@ class ManinSymbolList(Parent):
         """
         Return the weight of the Manin symbols in this :class:`ManinSymbolList`.
 
-        OUTPUT:
-
-        integer -- the weight of the Manin symbols in the list.
+        OUTPUT: integer; the weight of the Manin symbols in the list
 
         EXAMPLES::
 
@@ -396,7 +384,7 @@ class ManinSymbolList_group(ManinSymbolList):
     - ``weight`` -- integer weight
 
     - ``syms`` -- something with ``normalize`` and ``list`` methods,
-       e.g. :class:`~sage.modular.modsym.p1list.P1List`.
+      e.g. :class:`~sage.modular.modsym.p1list.P1List`
 
     EXAMPLES::
 
@@ -415,7 +403,7 @@ class ManinSymbolList_group(ManinSymbolList):
         - ``weight`` -- integer weight
 
         - ``syms`` -- something with ``normalize`` and ``list``
-           methods, e.g. :class:`~sage.modular.modsym.p1list.P1List`.
+          methods, e.g. :class:`~sage.modular.modsym.p1list.P1List`
 
         EXAMPLES::
 
@@ -463,12 +451,12 @@ class ManinSymbolList_group(ManinSymbolList):
 
         INPUT:
 
-        - ``j`` -- (int) a symbol index
+        - ``j`` -- integer; a symbol index
 
         OUTPUT:
 
         ``(k, s)`` where k is the index of the symbol obtained by acting on the
-        `j`'th symbol with `S`, and `s` is the parity of the `j`'th symbol
+        `j`-th symbol with `S`, and `s` is the parity of the `j`-th symbol
         (a Python ``int``, either 1 or -1).
 
         EXAMPLES::
@@ -500,7 +488,7 @@ class ManinSymbolList_group(ManinSymbolList):
 
     def _apply_S_only_0pm1(self):
         """
-        Return True if the coefficient when applying the S relation is
+        Return ``True`` if the coefficient when applying the S relation is
         always 0, 1, or -1.  This is useful for optimizing code in
         relation_matrix.py.
 
@@ -518,12 +506,12 @@ class ManinSymbolList_group(ManinSymbolList):
 
         INPUT:
 
-        - ``j`` -- (int) a symbol index
+        - ``j`` -- integer; a symbol index
 
         OUTPUT:
 
         ``(k, s)`` where k is the index of the symbol obtained by acting on the
-        `j`'th symbol with `I`, and `s` is the parity of the `j`'th symbol
+        `j`-th symbol with `I`, and `s` is the parity of the `j`-th symbol
         (a Python ``int``, either 1 or -1)
 
         EXAMPLES::
@@ -557,7 +545,7 @@ class ManinSymbolList_group(ManinSymbolList):
 
         INPUT:
 
-        - ``j`` -- (int) a symbol index
+        - ``j`` -- integer; a symbol index
 
         OUTPUT: see documentation for apply()
 
@@ -600,7 +588,7 @@ class ManinSymbolList_group(ManinSymbolList):
 
         INPUT:
 
-        - ``j`` -- (int) a symbol index
+        - ``j`` -- integer; a symbol index
 
         OUTPUT: see documentation for apply()
 
@@ -643,7 +631,7 @@ class ManinSymbolList_group(ManinSymbolList):
 
         INPUT:
 
-        - ``j`` -- (int) a symbol index
+        - ``j`` -- integer; a symbol index
 
         - ``m = [a, b, c, d]`` a list of 4 integers, which defines a 2x2 matrix
 
@@ -651,7 +639,7 @@ class ManinSymbolList_group(ManinSymbolList):
 
         a list of pairs `(j_i, \alpha_i)`, where each `\alpha_i` is a nonzero
         integer, `j_i` is an integer (index of the `j_i`-th Manin symbol), and
-        `\sum_i \alpha_i\*x_{j_i}` is the image of the j-th Manin symbol under
+        `\sum_i \alpha_i\*x_{j_i}` is the image of the `j`-th Manin symbol under
         the right action of the matrix [a,b;c,d]. Here the right action of
         `g = [a, b; c, d]` on a Manin symbol `[P(X,Y),(u,v)]` is
         `[P(aX+bY,cX+dY),(u,v)\*g]`.
@@ -714,9 +702,9 @@ class ManinSymbolList_gamma0(ManinSymbolList_group):
 
     INPUT:
 
-    - ``level`` -- (integer): the level.
+    - ``level`` -- integer; the level
 
-    - ``weight`` -- (integer): the weight.
+    - ``weight`` -- integer; the weight
 
     EXAMPLES::
 
@@ -732,7 +720,7 @@ class ManinSymbolList_gamma0(ManinSymbolList_group):
     """
     def __init__(self, level, weight):
         """
-        Constructor for a ModularSymbolList for Gamma_0(N)
+        Constructor for a ModularSymbolList for Gamma_0(N).
 
         EXAMPLES::
 
@@ -766,9 +754,9 @@ class ManinSymbolList_gamma1(ManinSymbolList_group):
 
     INPUT:
 
-    - ``level`` -- (integer): the level.
+    - ``level`` -- integer; the level
 
-    - ``weight`` -- (integer): the weight.
+    - ``weight`` -- integer; the weight
 
     EXAMPLES::
 
@@ -823,9 +811,9 @@ class ManinSymbolList_gamma_h(ManinSymbolList_group):
 
     INPUT:
 
-    - ``group`` -- (integer): the congruence subgroup.
+    - ``group`` -- integer; the congruence subgroup
 
-    - ``weight`` -- (integer): the weight.
+    - ``weight`` -- integer; the weight
 
     EXAMPLES::
 
@@ -865,7 +853,7 @@ class ManinSymbolList_gamma_h(ManinSymbolList_group):
 
     def group(self):
         """
-        Return the group associated to self.
+        Return the group associated to ``self``.
 
         EXAMPLES::
 
@@ -876,7 +864,7 @@ class ManinSymbolList_gamma_h(ManinSymbolList_group):
 
     def __repr__(self):
         """
-        Return the string representation of self.
+        Return the string representation of ``self``.
 
         EXAMPLES::
 
@@ -895,7 +883,7 @@ class ManinSymbolList_character(ManinSymbolList):
 
     - ``character`` -- (DirichletCharacter) the Dirichlet character
 
-    - ``weight`` -- (integer) the weight
+    - ``weight`` -- integer; the weight
 
     EXAMPLES::
 
@@ -915,9 +903,9 @@ class ManinSymbolList_character(ManinSymbolList):
 
         INPUT:
 
-        -  ``character`` -- (DirichletCharacter) the Dirichlet character
+        - ``character`` -- (DirichletCharacter) the Dirichlet character
 
-        -  ``weight`` -- (integer) the weight
+        - ``weight`` -- integer; the weight
 
         EXAMPLES::
 
@@ -970,9 +958,7 @@ class ManinSymbolList_character(ManinSymbolList):
         """
         Return the level of this :class:`ManinSymbolList`.
 
-        OUTPUT:
-
-        ``integer`` -- the level of the symbols in this list.
+        OUTPUT: integer; the level of the symbols in this list
 
         EXAMPLES::
 
@@ -990,17 +976,16 @@ class ManinSymbolList_character(ManinSymbolList):
 
         INPUT:
 
+        - ``j`` -- integer; the index of the symbol to act on
 
-        - ``j`` (integer): the index of the symbol to act on.
-
-        - ``m`` (list of ints):  `[a,b,c,d]` where `m = [a, b; c, d]` is the matrix to be applied.
-
+        - ``m`` -- list of integers `[a,b,c,d]` where `m = [a, b; c, d]` is the
+          matrix to be applied
 
         OUTPUT:
 
         A list of pairs `(j, c_i)`, where each `c_i` is an
         integer, `j` is an integer (the `j`-th Manin symbol), and the
-        sum `c_i*x_i` is the image of self under the right action
+        sum `c_i*x_i` is the image of ``self`` under the right action
         of the matrix `[a,b;c,d]`. Here the right action of
         `g = [a,b;c,d]` on a Manin symbol `[P(X,Y),(u,v)]` is by
         definition `[P(aX+bY,cX+dY),(u,v)*g]`.
@@ -1034,13 +1019,13 @@ class ManinSymbolList_character(ManinSymbolList):
 
         INPUT:
 
-        - ``j`` -- (integer) a symbol index.
+        - ``j`` -- integer; a symbol index
 
         OUTPUT:
 
         ``(k, s)`` where `k` is the index of the symbol obtained by acting
-        on the `j`'th symbol with `S`, and `s` is the parity of the
-        `j`'th symbol.
+        on the `j`-th symbol with `S`, and `s` is the parity of the
+        `j`-th symbol.
 
         EXAMPLES::
 
@@ -1063,7 +1048,7 @@ class ManinSymbolList_character(ManinSymbolList):
 
     def _apply_S_only_0pm1(self):
         """
-        Return True if the coefficient when applying the S relation is
+        Return ``True`` if the coefficient when applying the S relation is
         always 0, 1, or -1.  This is useful for optimizing code in
         relation_matrix.py.
 
@@ -1085,13 +1070,13 @@ class ManinSymbolList_character(ManinSymbolList):
 
         INPUT:
 
-        - ``j`` -- (integer) a symbol index
+        - ``j`` -- integer; a symbol index
 
         OUTPUT:
 
         ``(k, s)`` where `k` is the index of the symbol obtained by acting
-        on the `j`'th symbol with `I`, and `s` is the parity of the
-        `j`'th symbol.
+        on the `j`-th symbol with `I`, and `s` is the parity of the
+        `j`-th symbol.
 
         EXAMPLES::
 
@@ -1114,17 +1099,17 @@ class ManinSymbolList_character(ManinSymbolList):
 
     def apply_T(self, j):
         """
-        Apply the matrix `T=[0,1,-1,-1]` to the j-th Manin symbol.
+        Apply the matrix `T=[0,1,-1,-1]` to the `j`-th Manin symbol.
 
         INPUT:
 
-        - ``j`` -- (integer) a symbol index.
+        - ``j`` -- integer; a symbol index
 
         OUTPUT:
 
         A list of pairs `(j, c_i)`, where each `c_i` is an
         integer, `j` is an integer (the `j`-th Manin symbol), and the
-        sum `c_i*x_i` is the image of self under the right action
+        sum `c_i*x_i` is the image of ``self`` under the right action
         of the matrix `T`.
 
         EXAMPLES::
@@ -1161,13 +1146,13 @@ class ManinSymbolList_character(ManinSymbolList):
 
         INPUT:
 
-        - ``j`` -- (integer) a symbol index
+        - ``j`` -- integer; a symbol index
 
         OUTPUT:
 
         A list of pairs `(j, c_i)`, where each `c_i` is an
         integer, `j` is an integer (the `j`-th Manin symbol), and the
-        sum `c_i*x_i` is the image of self under the right action
+        sum `c_i*x_i` is the image of ``self`` under the right action
         of the matrix `T^2`.
 
         EXAMPLES::
@@ -1202,9 +1187,7 @@ class ManinSymbolList_character(ManinSymbolList):
         """
         Return the character of this :class:`ManinSymbolList_character` object.
 
-        OUTPUT:
-
-        The Dirichlet character of this Manin symbol list.
+        OUTPUT: the Dirichlet character of this Manin symbol list
 
         EXAMPLES::
 
@@ -1215,7 +1198,6 @@ class ManinSymbolList_character(ManinSymbolList):
             Manin Symbol List of weight 2 for Gamma1(4) with character [-1]
             sage: m.character()
             Dirichlet character modulo 4 of conductor 4 mapping 3 |--> -1
-
         """
         return self.__character
 
@@ -1268,7 +1250,7 @@ class ManinSymbolList_character(ManinSymbolList):
         INPUT:
 
         - ``x`` -- 3-tuple of integers ``(i,u,v)``, defining an element of this
-          list of Manin symbols, which need not be normalized.
+          list of Manin symbols, which need not be normalized
 
         OUTPUT:
 
