@@ -59,11 +59,12 @@ class FGP_Element(ModuleElement):
         """
         INPUT:
 
-        - ``parent`` -- parent module M
+        - ``parent`` -- parent module ``M``
 
-        - ``x`` -- element of M.V()
+        - ``x`` -- element of ``M.V()``
 
-        - ``check`` -- (default: ``True``) if True, verify that x in M.V()
+        - ``check`` -- boolean (default: ``True``); if ``True``, verify that x
+          in ``M.V()``
 
         EXAMPLES::
 
@@ -83,7 +84,8 @@ class FGP_Element(ModuleElement):
 
     def lift(self):
         """
-        Lift self to an element of V, where the parent of self is the quotient module V/W.
+        Lift ``self`` to an element of V, where the parent of ``self`` is the
+        quotient module V/W.
 
         EXAMPLES::
 
@@ -193,7 +195,7 @@ class FGP_Element(ModuleElement):
 
         INPUT:
 
-        - ``c`` -- an element of ``self.parent().base_ring()``.
+        - ``c`` -- an element of ``self.parent().base_ring()``
 
         OUTPUT:
 
@@ -238,7 +240,7 @@ class FGP_Element(ModuleElement):
 
         INPUT:
 
-        - ``c`` -- an element of ``self.parent().base_ring()``.
+        - ``c`` -- an element of ``self.parent().base_ring()``
 
         OUTPUT:
 
@@ -355,11 +357,9 @@ class FGP_Element(ModuleElement):
 
         INPUT:
 
-        - ``base_ring`` -- the desired base ring of the vector.
+        - ``base_ring`` -- the desired base ring of the vector
 
-        OUTPUT:
-
-        A vector over the base ring.
+        OUTPUT: a vector over the base ring
 
         EXAMPLES::
 
@@ -391,7 +391,7 @@ class FGP_Element(ModuleElement):
 
     def _richcmp_(self, right, op):
         """
-        Compare self and right.
+        Compare ``self`` and ``right``.
 
         EXAMPLES::
 
