@@ -249,7 +249,7 @@ class SteenrodModuleMixin:
 
         # A private function which transforms a vector in a given dimension
         # to a vector of global indices for the basis elements corresponding
-        # to the non-zero entries in the vector.  E.g.
+        # to the nonzero entries in the vector.  E.g.
         # _GetIndices(dim=2, vec=(1,0,1)) will return a vector of length two,
         # (a, b), where a is the index of the first vector in the basis for
         # the 2-dimensional part of the module, and b is the index of the
@@ -357,13 +357,12 @@ class SteenrodFPModule(FPModule, SteenrodModuleMixin):
 
         INPUT:
 
-        - ``k`` -- non-negative integer
+        - ``k`` -- nonnegative integer
         - ``top_dim`` -- (optional) stop the computation at this degree
-        - ``verbose`` -- (default: ``False``) whether log messages are printed
+        - ``verbose`` -- boolean (default: ``False``); whether log messages are
+          printed
 
-        OUTPUT:
-
-        A list of homomorphisms `[\epsilon, f_1, \ldots, f_k]` such that
+        OUTPUT: list of homomorphisms `[\epsilon, f_1, \ldots, f_k]` such that
 
         .. MATH::
 
