@@ -68,10 +68,10 @@ AUTHORS:
 import weakref
 
 from sage.categories.commutative_rings import CommutativeRings
+from sage.categories.fields import Fields
 from sage.categories.principal_ideal_domains import PrincipalIdealDomains
 from sage.categories.integral_domains import IntegralDomains
 from sage.modules import free_module
-from sage.rings.ring import Field
 import sage.matrix.matrix_space
 import sage.misc.latex as latex
 
@@ -168,7 +168,7 @@ def FreeQuadraticModule(base_ring, rank, inner_product_matrix,
     # elif not sparse and isinstance(base_ring,sage.rings.complex_double.ComplexDoubleField_class):
     #     M = ComplexDoubleQuadraticSpace_class(rank, inner_product_matrix=inner_product_matrix, sparse=False)
 
-    elif base_ring.is_field():
+    if base_ring in Fields():
         M = FreeQuadraticModule_ambient_field(
             base_ring, rank, sparse=sparse, inner_product_matrix=inner_product_matrix)
 
@@ -213,7 +213,7 @@ def QuadraticSpace(K, dimension, inner_product_matrix, sparse=False):
         ...
         TypeError: argument K (= Integer Ring) must be a field
     """
-    if not K.is_field():
+    if K not in Fields():
         raise TypeError(f"argument K (= {K}) must be a field")
     if sparse not in (True, False):
         raise TypeError("Argument sparse (= %s) must be a boolean." % sparse)
@@ -307,7 +307,8 @@ class FreeQuadraticModule_generic(free_module.FreeModule_generic):
         sage: M1 == M2
         False
     """
-    def __init__(self, base_ring, rank, degree, inner_product_matrix, sparse=False):
+    def __init__(self, base_ring, rank, degree,
+                 inner_product_matrix, sparse=False) -> None:
         """
         Create the free module of given rank over the given ``base_ring``.
 
@@ -589,7 +590,8 @@ class FreeQuadraticModule_generic_pid(free_module.FreeModule_generic_pid,
     """
     Class of all free modules over a PID.
     """
-    def __init__(self, base_ring, rank, degree, inner_product_matrix, sparse=False):
+    def __init__(self, base_ring, rank, degree,
+                 inner_product_matrix, sparse=False) -> None:
         """
         Create a free module over a PID.
 
@@ -696,7 +698,8 @@ class FreeQuadraticModule_generic_field(free_module.FreeModule_generic_field,
     """
     Base class for all free modules over fields.
     """
-    def __init__(self, base_field, dimension, degree, inner_product_matrix, sparse=False):
+    def __init__(self, base_field, dimension, degree,
+                 inner_product_matrix, sparse=False) -> None:
         """
         Create a vector space over a field.
 
@@ -718,10 +721,11 @@ class FreeQuadraticModule_generic_field(free_module.FreeModule_generic_field,
             [0 0 0 0 0 1 0]
             [0 0 0 0 0 0 1]
         """
-        if not isinstance(base_field, Field):
-            raise TypeError("the base_field (=%s) must be a field" % base_field)
+        if base_field not in Fields():
+            raise TypeError(f"the base_field (={base_field}) must be a field")
         free_module.FreeModule_generic_field.__init__(
-            self, base_field=base_field, dimension=dimension, degree=degree, sparse=sparse)
+            self, base_field=base_field, dimension=dimension,
+            degree=degree, sparse=sparse)
         self._inner_product_matrix = inner_product_matrix
 
     def span(self, gens, check=True, already_echelonized=False):
@@ -820,7 +824,8 @@ class FreeQuadraticModule_ambient(free_module.FreeModule_ambient,
     """
     Ambient free module over a commutative ring.
     """
-    def __init__(self, base_ring, rank, inner_product_matrix, sparse=False):
+    def __init__(self, base_ring, rank,
+                 inner_product_matrix, sparse=False) -> None:
         """
         The free module of given rank over the given ``base_ring``.
 
@@ -838,7 +843,7 @@ class FreeQuadraticModule_ambient(free_module.FreeModule_ambient,
         free_module.FreeModule_ambient.__init__(self, base_ring=base_ring, rank=rank, sparse=sparse)
         self._inner_product_matrix = inner_product_matrix
 
-    def _repr_(self):
+    def _repr_(self) -> str:
         """
         The printing representation of ``self``.
 
@@ -872,7 +877,7 @@ class FreeQuadraticModule_ambient(free_module.FreeModule_ambient,
         return "Ambient free quadratic module of rank %s over %s\n" % (self.rank(), self.base_ring()) + \
             "Inner product matrix:\n%s" % self.inner_product_matrix()
 
-    def _latex_(self):
+    def _latex_(self) -> str:
         r"""
         Return a latex representation of this ambient free quadratic module.
 
@@ -944,7 +949,8 @@ class FreeQuadraticModule_ambient_domain(free_module.FreeModule_ambient_domain,
     """
     Ambient free quadratic module over an integral domain.
     """
-    def __init__(self, base_ring, rank, inner_product_matrix, sparse=False):
+    def __init__(self, base_ring, rank,
+                 inner_product_matrix, sparse=False) -> None:
         """
         EXAMPLES::
 
@@ -955,7 +961,7 @@ class FreeQuadraticModule_ambient_domain(free_module.FreeModule_ambient_domain,
         free_module.FreeModule_ambient.__init__(self, base_ring=base_ring, rank=rank, sparse=sparse)
         self._inner_product_matrix = inner_product_matrix
 
-    def _repr_(self):
+    def _repr_(self) -> str:
         """
         The printing representation of ``self``.
 
@@ -1035,7 +1041,8 @@ class FreeQuadraticModule_ambient_pid(free_module.FreeModule_ambient_pid,
     """
     Ambient free quadratic module over a principal ideal domain.
     """
-    def __init__(self, base_ring, rank, inner_product_matrix, sparse=False):
+    def __init__(self, base_ring, rank,
+                 inner_product_matrix, sparse=False) -> None:
         """
         Create the ambient free module of given rank over the given
         principal ideal domain.
@@ -1064,7 +1071,7 @@ class FreeQuadraticModule_ambient_pid(free_module.FreeModule_ambient_pid,
         free_module.FreeModule_ambient_pid.__init__(self, base_ring=base_ring, rank=rank, sparse=sparse)
         self._inner_product_matrix = inner_product_matrix
 
-    def _repr_(self):
+    def _repr_(self) -> str:
         """
         The printing representation of ``self``.
 
@@ -1120,7 +1127,8 @@ class FreeQuadraticModule_ambient_field(free_module.FreeModule_ambient_field,
                                         FreeQuadraticModule_generic_field,
                                         FreeQuadraticModule_ambient_pid):
 
-    def __init__(self, base_field, dimension, inner_product_matrix, sparse=False):
+    def __init__(self, base_field, dimension,
+                 inner_product_matrix, sparse=False) -> None:
         """
         Create the ambient vector space of given dimension over the given field.
 
@@ -1158,7 +1166,7 @@ class FreeQuadraticModule_ambient_field(free_module.FreeModule_ambient_field,
             self, base_field=base_field, dimension=dimension, sparse=sparse)
         self._inner_product_matrix = inner_product_matrix
 
-    def _repr_(self):
+    def _repr_(self) -> str:
         """
         The printing representation of ``self``.
 
@@ -1239,7 +1247,7 @@ class FreeQuadraticModule_submodule_with_basis_pid(free_module.FreeModule_submod
     """
     def __init__(self, ambient, basis, inner_product_matrix,
                  check=True, echelonize=False, echelonized_basis=None,
-                 already_echelonized=False):
+                 already_echelonized=False) -> None:
         """
         Create a free module with basis over a PID.
 
@@ -1282,7 +1290,7 @@ class FreeQuadraticModule_submodule_with_basis_pid(free_module.FreeModule_submod
             echelonize=echelonize, echelonized_basis=echelonized_basis, already_echelonized=already_echelonized)
         self._inner_product_matrix = inner_product_matrix
 
-    def _repr_(self):
+    def _repr_(self) -> str:
         """
         The printing representation of ``self``.
 
@@ -1326,7 +1334,7 @@ class FreeQuadraticModule_submodule_with_basis_pid(free_module.FreeModule_submod
                 "Inner product matrix:\n%r" % self.inner_product_matrix()
         return s
 
-    def _latex_(self):
+    def _latex_(self) -> str:
         r"""
         Return latex representation of this free module.
 
@@ -1410,7 +1418,9 @@ class FreeQuadraticModule_submodule_pid(free_module.FreeModule_submodule_pid,
         sage: loads(v.dumps()) == v
         True
     """
-    def __init__(self, ambient, gens, inner_product_matrix, check=True, already_echelonized=False):
+    def __init__(self, ambient, gens,
+                 inner_product_matrix, check=True,
+                 already_echelonized=False) -> None:
         """
         Create an embedded free module over a PID.
 
@@ -1428,7 +1438,7 @@ class FreeQuadraticModule_submodule_pid(free_module.FreeModule_submodule_pid,
             self, ambient=ambient, gens=gens, check=check, already_echelonized=already_echelonized)
         self._inner_product_matrix = inner_product_matrix
 
-    def _repr_(self):
+    def _repr_(self) -> str:
         """
         The printing representation of ``self``.
 
@@ -1507,7 +1517,8 @@ class FreeQuadraticModule_submodule_with_basis_field(free_module.FreeModule_subm
         True
     """
     def __init__(self, ambient, basis, inner_product_matrix,
-                 check=True, echelonize=False, echelonized_basis=None, already_echelonized=False):
+                 check=True, echelonize=False, echelonized_basis=None,
+                 already_echelonized=False) -> None:
         """
         Create a vector space with given basis.
 
@@ -1536,7 +1547,7 @@ class FreeQuadraticModule_submodule_with_basis_field(free_module.FreeModule_subm
             echelonize=echelonize, echelonized_basis=echelonized_basis, already_echelonized=already_echelonized)
         self._inner_product_matrix = inner_product_matrix
 
-    def _repr_(self):
+    def _repr_(self) -> str:
         """
         The printing representation of ``self``.
 
@@ -1627,7 +1638,8 @@ class FreeQuadraticModule_submodule_field(free_module.FreeModule_submodule_field
         sage: vector(QQ, W.coordinates(v)) * W.basis_matrix()
         (1, 5, 9)
     """
-    def __init__(self, ambient, gens, inner_product_matrix, check=True, already_echelonized=False):
+    def __init__(self, ambient, gens, inner_product_matrix, check=True,
+                 already_echelonized=False) -> None:
         """
         Create an embedded vector subspace with echelonized basis.
 
@@ -1645,7 +1657,7 @@ class FreeQuadraticModule_submodule_field(free_module.FreeModule_submodule_field
             self, ambient=ambient, gens=gens, check=check, already_echelonized=already_echelonized)
         self._inner_product_matrix = inner_product_matrix
 
-    def _repr_(self):
+    def _repr_(self) -> str:
         """
         The default printing representation of ``self``.
 
