@@ -24,14 +24,13 @@ from sage.categories.monoids import Monoids
 from sage.categories.semigroups import Semigroups
 from sage.misc.cachefunc import cached_method
 from sage.misc.lazy_attribute import lazy_attribute
+from sage.quivers.paths import QuiverPath
+from sage.quivers.representation import QuiverRep
 from sage.rings.integer import Integer
 from sage.rings.integer_ring import ZZ
 from sage.structure.parent import Parent
 from sage.structure.unique_representation import UniqueRepresentation
 
-from .paths import QuiverPath
-from .representation import QuiverRep
-
 #########################
 # Some auxiliary function to create generating functions to count paths.
 
@@ -186,7 +185,7 @@ class PathSemigroup(UniqueRepresentation, Parent):
         names = ['e_{0}'.format(v) for v in Q.vertex_iterator()]
         names += list(self._labels)
         self._quiver = Q
-        if Q.num_verts() == 1:
+        if Q.n_vertices() == 1:
             cat = cat.join([cat, Monoids()])
         else:
             cat = cat.join([cat, Semigroups()])
@@ -205,7 +204,7 @@ class PathSemigroup(UniqueRepresentation, Parent):
             sage: Q.path_semigroup()
             Monoid formed by the directed paths of Looped multi-digraph on 1 vertex
         """
-        if self._quiver.num_verts() != 1:
+        if self._quiver.n_vertices() != 1:
             return "Partial semigroup formed by the directed paths of {}".format(self._quiver)
         return "Monoid formed by the directed paths of {}".format(self._quiver)
 
@@ -261,7 +260,7 @@ class PathSemigroup(UniqueRepresentation, Parent):
         # internally, directly using the backend to make things faster.
         sQ = self._quiver._backend
         oQ = other.quiver()._backend
-        if sQ.num_verts() < oQ.num_verts():
+        if sQ.n_vertices() < oQ.n_vertices():
             return False
         if any(not sQ.has_vertex(v) for v in oQ.iterator_verts(None)):
             return False
@@ -437,7 +436,7 @@ class PathSemigroup(UniqueRepresentation, Parent):
             7
         """
         Q = self._quiver
-        return Q.num_verts() + Q.num_edges()
+        return Q.n_vertices() + Q.n_edges()
 
     @cached_method
     def gen(self, i):
