@@ -1,4 +1,3 @@
-# sage_setup: distribution = sagemath-repl
 """
 The Sage Preparser
 
@@ -1737,11 +1736,11 @@ def preparse(line, reset=True, do_time=False, ignore_prompts=False,
         8
 
         sage: preparse("A \\ B")
-        'A  * BackslashOperator() * B'
+        'A \\ B'
         sage: preparse("A^2 \\ B + C")
-        'A**Integer(2)  * BackslashOperator() * B + C'
+        'A**Integer(2) \\ B + C'
         sage: preparse("a \\ b \\") # There is really only one backslash here, it is just being escaped.
-        'a  * BackslashOperator() * b \\'
+        'a \\ b \\'
 
         sage: preparse("time R.<x> = ZZ[]", do_time=True)
         '__time__ = cputime(); __wall__ = walltime(); R = ZZ[\'x\']; print("Time: CPU {:.2f} s, Wall: {:.2f} s".format(cputime(__time__), walltime(__wall__))); (x,) = R._first_ngens(1)'
@@ -1853,9 +1852,6 @@ def preparse(line, reset=True, do_time=False, ignore_prompts=False,
     # f(x,y) = x^3 - sin(y)
     L = preparse_calculus(L)
 
-    # Backslash
-    L = re.sub(r'''\\\s*([^\t ;#])''', r' * BackslashOperator() * \1', L)
-
     if do_time:
         # Time keyword
         L = re.sub(r';time;(\s*)(\S[^;\n]*)',
