@@ -1,4 +1,3 @@
-# sage_setup: distribution = sagemath-repl
 """
 IPython Backend for the Sage Rich Output System
 
@@ -16,7 +15,6 @@ This module defines the IPython backends for
 # ****************************************************************************
 
 import os
-import sys
 import html
 from IPython.display import publish_display_data
 from sage.repl.rich_output.backend_base import BackendBase
@@ -25,7 +23,7 @@ from sage.repl.rich_output.output_catalog import *
 
 class BackendIPython(BackendBase):
     """
-    Common base for the IPython UIs
+    Common base for the IPython UIs.
 
     EXAMPLES::
 
@@ -38,11 +36,11 @@ class BackendIPython(BackendBase):
 
     def install(self, **kwds):
         """
-        Switch the Sage rich output to the IPython backend
+        Switch the Sage rich output to the IPython backend.
 
         INPUT:
 
-        - ``shell`` -- keyword argument. The IPython shell.
+        - ``shell`` -- keyword argument; the IPython shell
 
         No tests since switching away from the doctest rich output
         backend will break the doctests.
@@ -70,7 +68,7 @@ class BackendIPython(BackendBase):
 
         INPUT:
 
-        - ``obj`` -- anything.
+        - ``obj`` -- anything
 
         EXAMPLES::
 
@@ -94,9 +92,7 @@ class BackendIPython(BackendBase):
 
         Same as :meth:`displayhook`.
 
-        OUTPUT:
-
-        This method does not return anything.
+        OUTPUT: this method does not return anything
 
         EXAMPLES::
 
@@ -115,7 +111,7 @@ class BackendIPython(BackendBase):
 
 class BackendIPythonCommandline(BackendIPython):
     """
-    Backend for the IPython Command Line
+    Backend for the IPython Command Line.
 
     EXAMPLES::
 
@@ -126,7 +122,7 @@ class BackendIPythonCommandline(BackendIPython):
 
     def default_preferences(self):
         """
-        Return the backend's display preferences
+        Return the backend's display preferences.
 
         The default for the commandline is to not plot graphs since
         the launching of an external viewer is considered too
@@ -153,11 +149,9 @@ class BackendIPythonCommandline(BackendIPython):
 
     def _repr_(self):
         """
-        Return a string representation
+        Return a string representation.
 
-        OUTPUT:
-
-        String.
+        OUTPUT: string
 
         EXAMPLES::
 
@@ -199,7 +193,7 @@ class BackendIPythonCommandline(BackendIPython):
 
     def displayhook(self, plain_text, rich_output):
         """
-        Backend implementation of the displayhook
+        Backend implementation of the displayhook.
 
         INPUT:
 
@@ -291,9 +285,7 @@ class BackendIPythonCommandline(BackendIPython):
 
         Same as :meth:`displayhook`.
 
-        OUTPUT:
-
-        This method does not return anything.
+        OUTPUT: this method does not return anything
 
         EXAMPLES::
 
@@ -313,10 +305,10 @@ class BackendIPythonCommandline(BackendIPython):
 
         INPUT:
 
-        - ``image_file`` -- string. File name of the image file.
+        - ``image_file`` -- string; file name of the image file
 
-        - ``plain_text`` -- string. The plain text representation of
-          the image file.
+        - ``plain_text`` -- string; the plain text representation of
+          the image file
 
         OUTPUT:
 
@@ -344,19 +336,19 @@ class BackendIPythonCommandline(BackendIPython):
 
     def launch_jmol(self, output_jmol, plain_text):
         """
-        Launch the stand-alone jmol viewer
+        Launch the stand-alone jmol viewer.
 
         INPUT:
 
         - ``output_jmol`` --
-          :class:`~sage.repl.rich_output.output_graphics3d.OutputSceneJmol`. The
-          scene to launch Jmol with.
+          :class:`~sage.repl.rich_output.output_graphics3d.OutputSceneJmol`; the
+          scene to launch Jmol with
 
-        - ``plain_text`` -- string. The plain text representation.
+        - ``plain_text`` -- string; the plain text representation
 
         OUTPUT:
 
-        String. Human-readable message indicating that the viewer was launched.
+        string; human-readable message indicating that the viewer was launched.
 
         EXAMPLES::
 
@@ -380,15 +372,13 @@ class BackendIPythonCommandline(BackendIPython):
 
     def is_in_terminal(self):
         """
-        Test whether the UI is meant to run in a terminal
+        Test whether the UI is meant to run in a terminal.
 
         See
         :meth:`sage.repl.rich_output.display_manager.DisplayManager.is_in_terminal`
         for details.
 
-        OUTPUT:
-
-        ``True`` for the IPython commandline.
+        OUTPUT: ``True`` for the IPython commandline
 
         EXAMPLES::
 
@@ -401,11 +391,9 @@ class BackendIPythonCommandline(BackendIPython):
 
     def threejs_offline_scripts(self):
         """
-        Three.js script for the IPython command line
+        Three.js script for the IPython command line.
 
-        OUTPUT:
-
-        String containing script tag
+        OUTPUT: string containing script tag
 
         EXAMPLES::
 
@@ -436,7 +424,7 @@ IFRAME_TEMPLATE = """
 
 class BackendIPythonNotebook(BackendIPython):
     """
-    Backend for the IPython Notebook
+    Backend for the IPython Notebook.
 
     EXAMPLES::
 
@@ -447,11 +435,9 @@ class BackendIPythonNotebook(BackendIPython):
 
     def _repr_(self):
         """
-        Return string representation of the backend
+        Return string representation of the backend.
 
-        OUTPUT:
-
-        String.
+        OUTPUT: string
 
         EXAMPLES::
 
@@ -497,7 +483,7 @@ class BackendIPythonNotebook(BackendIPython):
 
     def displayhook(self, plain_text, rich_output):
         """
-        Backend implementation of the displayhook
+        Backend implementation of the displayhook.
 
         INPUT:
 
@@ -537,7 +523,7 @@ class BackendIPythonNotebook(BackendIPython):
         elif isinstance(rich_output, OutputLatex):
             return ({'text/latex': rich_output.latex.get_str(),
                      'text/plain': plain_text.text.get_str(),
-            }, {})
+                     }, {})
         elif isinstance(rich_output, OutputHtml):
             data = {'text/html': rich_output.html.get_str(),
                     'text/plain': plain_text.text.get_str()}
@@ -547,29 +533,29 @@ class BackendIPythonNotebook(BackendIPython):
         elif isinstance(rich_output, OutputImagePng):
             return ({'image/png': rich_output.png.get(),
                      'text/plain': plain_text.text.get_str(),
-            }, {})
+                     }, {})
         elif isinstance(rich_output, OutputImageGif):
             return ({'text/html': rich_output.html_fragment(),
                      'text/plain': plain_text.text.get_str(),
-            }, {})
+                     }, {})
         elif isinstance(rich_output, OutputImageJpg):
             return ({'image/jpeg': rich_output.jpg.get(),
                      'text/plain': plain_text.text.get_str(),
-            }, {})
+                     }, {})
         elif isinstance(rich_output, OutputImageSvg):
             return ({'image/svg+xml': rich_output.svg.get(),
                      'text/plain': plain_text.text.get_str(),
-            }, {})
+                     }, {})
         elif isinstance(rich_output, OutputImagePdf):
             return ({'image/png': rich_output.png.get(),
                      'text/plain': plain_text.text.get_str(),
-            }, {})
+                     }, {})
         elif isinstance(rich_output, OutputSceneJmol):
             from sage.repl.display.jsmol_iframe import JSMolHtml
             jsmol = JSMolHtml(rich_output, height=500)
             return ({'text/html': jsmol.iframe(),
                      'text/plain': plain_text.text.get_str(),
-            }, {})
+                     }, {})
         elif isinstance(rich_output, OutputSceneThreejs):
             escaped_html = html.escape(rich_output.html.get_str())
             iframe = IFRAME_TEMPLATE.format(
@@ -579,17 +565,15 @@ class BackendIPythonNotebook(BackendIPython):
             )
             return ({'text/html': iframe,
                      'text/plain': plain_text.text.get_str(),
-            }, {})
+                     }, {})
         else:
             raise TypeError('rich_output type not supported')
 
     def threejs_offline_scripts(self):
         """
-        Three.js script for the IPython notebook
+        Three.js script for the IPython notebook.
 
-        OUTPUT:
-
-        String containing script tag
+        OUTPUT: string containing script tag
 
         EXAMPLES::
 
