@@ -53,12 +53,11 @@ AUTHORS:
 
 - Vincent Delecroix (November 2013): additional methods
 """
-
 from sage.misc.abstract_method import abstract_method
 from sage.misc.fast_methods import WithEqualityById
-
 from sage.rings.finite_rings.finite_field_base import FiniteField
 from sage.rings.ring import Field
+from sage.sets.family import AbstractFamily
 from sage.structure.element import Element, FieldElement
 from sage.structure.richcmp import richcmp
 
@@ -74,7 +73,6 @@ class AlgebraicClosureFiniteFieldElement(FieldElement):
         z2
         sage: type(F.gen(2))
         <class 'sage.rings.algebraic_closure_finite_field.AlgebraicClosureFiniteField_pseudo_conway_with_category.element_class'>
-
     """
     def __init__(self, parent, value):
         """
@@ -88,7 +86,6 @@ class AlgebraicClosureFiniteFieldElement(FieldElement):
             The ``_test_pickling`` test has to be skipped because
             there is no coercion map between the parents of ``x``
             and ``loads(dumps(x))``.
-
         """
         if isinstance(value, Element) and isinstance(value.parent(), FiniteField):
             n = value.parent().degree()
@@ -162,7 +159,6 @@ class AlgebraicClosureFiniteFieldElement(FieldElement):
             sage: F = GF(3).algebraic_closure()
             sage: F._repr_()
             'Algebraic closure of Finite Field of size 3'
-
         """
         return self._value._repr_()
 
@@ -201,7 +197,6 @@ class AlgebraicClosureFiniteFieldElement(FieldElement):
             sage: F = GF(3).algebraic_closure()
             sage: F.gen(2) + F.gen(3)
             z6^5 + 2*z6^4 + 2*z6^3 + z6^2 + 2*z6 + 1
-
         """
         F = self.parent()
         x, y = F._to_common_subfield(self, right)
@@ -216,7 +211,6 @@ class AlgebraicClosureFiniteFieldElement(FieldElement):
             sage: F = GF(3).algebraic_closure()
             sage: F.gen(2) - F.gen(3)
             z6^4 + 2*z6^3 + z6^2 + 2*z6
-
         """
         F = self.parent()
         x, y = F._to_common_subfield(self, right)
@@ -231,7 +225,6 @@ class AlgebraicClosureFiniteFieldElement(FieldElement):
             sage: F = GF(3).algebraic_closure()
             sage: F.gen(2) * F.gen(3)
             z6^5 + 2*z6^4 + z6^2 + 2
-
         """
         F = self.parent()
         x, y = F._to_common_subfield(self, right)
@@ -246,7 +239,6 @@ class AlgebraicClosureFiniteFieldElement(FieldElement):
             sage: F = GF(3).algebraic_closure()
             sage: F.gen(2) / F.gen(3)
             z6^5 + 2*z6^4 + z6^3 + 1
-
         """
         F = self.parent()
         x, y = F._to_common_subfield(self, right)
@@ -282,7 +274,6 @@ class AlgebraicClosureFiniteFieldElement(FieldElement):
               From: Finite Field of size 3
               To:   Finite Field in z3 of size 3^3
               Defn: 1 |--> 1
-
         """
         F = self.parent()
         l = self._level
@@ -304,7 +295,6 @@ class AlgebraicClosureFiniteFieldElement(FieldElement):
             z6^5 + 2*z6^4 + 2*z6^3 + z6^2 + 2*z6 + 2
             sage: latex(s)
             z_{6}^{5} + 2 z_{6}^{4} + 2 z_{6}^{3} + z_{6}^{2} + 2 z_{6} + 2
-
         """
         return self._value._latex_()
 
@@ -318,7 +308,6 @@ class AlgebraicClosureFiniteFieldElement(FieldElement):
             sage: F = GF(11).algebraic_closure()
             sage: F.gen(3).minpoly()
             x^3 + 2*x + 9
-
         """
         return self._value.minpoly()
 
@@ -335,7 +324,6 @@ class AlgebraicClosureFiniteFieldElement(FieldElement):
             sage: F = GF(3).algebraic_closure()
             sage: F.gen(2).is_square()
             True
-
         """
         return True
 
@@ -384,7 +372,6 @@ class AlgebraicClosureFiniteFieldElement(FieldElement):
         .. TODO::
 
             This function could probably be made faster.
-
         """
         from sage.rings.integer import Integer
         F = self.parent()
@@ -414,7 +401,6 @@ class AlgebraicClosureFiniteFieldElement(FieldElement):
             16806
             sage: (K.gen(1) + K.gen(2) + K.gen(3)).multiplicative_order()
             7353
-
         """
         return self._value.multiplicative_order()
 
@@ -436,7 +422,6 @@ class AlgebraicClosureFiniteFieldElement(FieldElement):
             t3^2 + t3 + 1
             sage: s.pth_power(3).parent() is K
             True
-
         """
         return self.__class__(self.parent(), self._value.pth_power(k))
 
@@ -458,7 +443,6 @@ class AlgebraicClosureFiniteFieldElement(FieldElement):
             t3^2 + t3 + 1
             sage: s.pth_root(2).parent() is K
             True
-
         """
         return self.__class__(self.parent(), self._value.pth_root(k))
 
@@ -468,8 +452,8 @@ class AlgebraicClosureFiniteFieldElement(FieldElement):
 
         INPUT:
 
-        - ``minimal`` -- boolean (default: ``False``).  If ``True``,
-          always return the smallest subfield containing ``self``.
+        - ``minimal`` -- boolean (default: ``False``); if ``True``,
+          always return the smallest subfield containing ``self``
 
         OUTPUT:
 
@@ -533,7 +517,6 @@ class AlgebraicClosureFiniteFieldElement(FieldElement):
               Defn: z2 |--> z4^3 + z4^2 + z4 + 3
             sage: f(b)
             z4^3 + z4^2 + z4 + 4
-
         """
         Fbar = self.parent()
         x = self._value
@@ -621,7 +604,6 @@ class AlgebraicClosureFiniteField_generic(Field):
             sage: F = AlgebraicClosureFiniteField(GF(p), 'z')
             sage: F.characteristic() == p
             True
-
         """
         return self.base_ring().characteristic()
 
@@ -644,7 +626,6 @@ class AlgebraicClosureFiniteField_generic(Field):
             Traceback (most recent call last):
             ...
             ValueError: no conversion defined between different algebraic closures
-
         """
         if isinstance(x, self.element_class):
             if x.parent() is not self:
@@ -663,7 +644,6 @@ class AlgebraicClosureFiniteField_generic(Field):
             sage: F = GF(7).algebraic_closure()
             sage: F.has_coerce_map_from(Integers())
             True
-
         """
         if other is self:
             return True
@@ -682,7 +662,6 @@ class AlgebraicClosureFiniteField_generic(Field):
             sage: F = AlgebraicClosureFiniteField(GF(5), 'z')
             sage: F._repr_()
             'Algebraic closure of Finite Field of size 5'
-
         """
         return 'Algebraic closure of %s' % self.base_ring()
 
@@ -710,7 +689,6 @@ class AlgebraicClosureFiniteField_generic(Field):
             Finite Field in z6 of size 3^6
             sage: y.parent()
             Finite Field in z6 of size 3^6
-
         """
         if x._level == y._level:
             return x._value, y._value
@@ -753,7 +731,6 @@ class AlgebraicClosureFiniteField_generic(Field):
             Traceback (most recent call last):
             ...
             NotImplementedError: <abstract method _get_im_gen at ...>
-
         """
 
     def _subfield(self, n):
@@ -765,7 +742,6 @@ class AlgebraicClosureFiniteField_generic(Field):
             sage: F = GF(3).algebraic_closure()
             sage: F._subfield(4)
             Finite Field in z4 of size 3^4
-
         """
         if n == 1:
             return self.base_ring()
@@ -797,7 +773,6 @@ class AlgebraicClosureFiniteField_generic(Field):
                From: Finite Field in z4 of size 3^4
                To:   Algebraic closure of Finite Field of size 3
                Defn: z4 |--> z4)
-
         """
         Fn = self._subfield(n)
         return Fn, Fn.hom( (self.gen(n),), check=False)
@@ -820,7 +795,6 @@ class AlgebraicClosureFiniteField_generic(Field):
               From: Finite Field in z2 of size 3^2
               To:   Finite Field in z4 of size 3^4
               Defn: z2 |--> 2*z4^3 + 2*z4^2 + 1
-
         """
         if m.divides(n):
             # check=False is required to avoid "coercion hell": an
@@ -840,7 +814,6 @@ class AlgebraicClosureFiniteField_generic(Field):
             sage: from sage.rings.algebraic_closure_finite_field import AlgebraicClosureFiniteField
             sage: AlgebraicClosureFiniteField(GF(5), 'z').ngens()
             +Infinity
-
         """
         from sage.rings.infinity import Infinity
         return Infinity
@@ -855,12 +828,11 @@ class AlgebraicClosureFiniteField_generic(Field):
             sage: F = AlgebraicClosureFiniteField(GF(5), 'z')
             sage: F.gen(2)
             z2
-
         """
         F = self._subfield(n)
         return self(F.gen())
 
-    def gens(self):
+    def gens(self) -> AbstractFamily:
         """
         Return a family of generators of ``self``.
 
@@ -892,7 +864,6 @@ class AlgebraicClosureFiniteField_generic(Field):
             sage: F = AlgebraicClosureFiniteField(GF(5), 'z')
             sage: F._first_ngens(3)
             (1, z2, z3)
-
         """
         return tuple(self.gen(i + 1) for i in range(n))
 
@@ -908,7 +879,6 @@ class AlgebraicClosureFiniteField_generic(Field):
             sage: F = AlgebraicClosureFiniteField(GF(5), 'z')
             sage: F.algebraic_closure() is F
             True
-
         """
         return self
 
@@ -920,7 +890,6 @@ class AlgebraicClosureFiniteField_generic(Field):
             sage: F = AlgebraicClosureFiniteField(GF(5), 'w')
             sage: F.an_element()  # indirect doctest
             w2
-
         """
         return self.gen(2)
 
@@ -933,7 +902,6 @@ class AlgebraicClosureFiniteField_generic(Field):
             sage: F = GF(7).algebraic_closure()
             sage: F.some_elements()
             (1, z2, z3 + 1)
-
         """
         return (self(1), self.gen(2), 1+self.gen(3))
 
@@ -962,7 +930,6 @@ class AlgebraicClosureFiniteField_generic(Field):
             ....:     p = R.random_element(degree=randint(2,8))
             ....:     for r in p.roots(K, multiplicities=False):
             ....:         assert p(r).is_zero(), "r={} is not a root of p={}".format(r,p)
-
         """
         from sage.arith.functions import lcm
         from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
@@ -975,28 +942,27 @@ class AlgebraicClosureFiniteField_generic(Field):
 
         new_coeffs = [self.inclusion(c[0].degree(), l)(c[1]) for c in coeffs]
 
-        polys = [(g,m,l,phi) for g,m in P(new_coeffs).factor()]
+        polys = [(g, m, l, phi) for g, m in P(new_coeffs).factor()]
         roots = []    # a list of pair (root,multiplicity)
         while polys:
-            g,m,l,phi = polys.pop()
+            g, m, l, phi = polys.pop()
 
-            if g.degree() == 1: # found a root
+            if g.degree() == 1:  # found a root
                 r = phi(-g.constant_coefficient())
-                roots.append((r,m))
-            else: # look at the extension of degree g.degree() which contains at
-                  # least one root of g
+                roots.append((r, m))
+            else:
+                # look at the extension of degree g.degree() which
+                # contains at least one root of g
                 ll = l * g.degree()
                 psi = self.inclusion(l, ll)
                 FF, pphi = self.subfield(ll)
-                # note: there is no coercion from the l-th subfield to the ll-th
-                # subfield. The line below does the conversion manually.
+                # note: there is no coercion from the l-th subfield to
+                # the ll-th subfield. The line below does the
+                # conversion manually.
                 g = PolynomialRing(FF, 'x')([psi(_) for _ in g])
-                polys.extend((gg,m,ll,pphi) for gg,_ in g.factor())
+                polys.extend((gg, m, ll, pphi) for gg, _ in g.factor())
 
-        if multiplicities:
-            return roots
-        else:
-            return [r[0] for r in roots]
+        return roots if multiplicities else [r[0] for r in roots]
 
     def _factor_univariate_polynomial(self, p, **kwds):
         r"""
@@ -1013,7 +979,6 @@ class AlgebraicClosureFiniteField_generic(Field):
             sage: for d in range(10):
             ....:     p = R.random_element(degree=randint(2,8))
             ....:     assert p.factor().prod() == p, "error in the factorization of p={}".format(p)
-
         """
         from sage.structure.factorization import Factorization
         R = p.parent()
@@ -1045,7 +1010,6 @@ class AlgebraicClosureFiniteField_pseudo_conway(WithEqualityById, AlgebraicClosu
         sage: F5 = GF(5).algebraic_closure()
         sage: F3 == F5
         False
-
     """
     def __init__(self, base_ring, name, category=None, lattice=None, use_database=True):
         """
@@ -1056,18 +1020,18 @@ class AlgebraicClosureFiniteField_pseudo_conway(WithEqualityById, AlgebraicClosu
           accepted.
 
         - ``name`` -- prefix to use for generators of the finite
-          subfields.
+          subfields
 
         - ``category`` -- if provided, specifies the category in which
-          this algebraic closure will be placed.
+          this algebraic closure will be placed
 
         - ``lattice`` -- :class:`~sage.rings.finite_rings.conway_polynomials.PseudoConwayPolynomialLattice`
-          (default: None).  If provided, use this pseudo-Conway
+          (default: ``None``); if provided, use this pseudo-Conway
           polynomial lattice to construct an algebraic closure.
 
-        - ``use_database`` -- boolean.  If True (default), use actual
+        - ``use_database`` -- boolean.  If ``True`` (default), use actual
           Conway polynomials whenever they are available in the
-          database.  If False, always compute pseudo-Conway
+          database.  If ``False``, always compute pseudo-Conway
           polynomials from scratch.
 
         TESTS::
@@ -1098,7 +1062,6 @@ class AlgebraicClosureFiniteField_pseudo_conway(WithEqualityById, AlgebraicClosu
             be made to compare equal, and ``_test_elements`` has to be
             skipped for the reason described in
             :meth:`AlgebraicClosureFiniteFieldElement.__init__`.
-
         """
         if not (isinstance(base_ring, FiniteField) and base_ring.is_prime_field()):
             raise NotImplementedError('algebraic closures of finite fields are only implemented for prime fields')
@@ -1122,7 +1085,6 @@ class AlgebraicClosureFiniteField_pseudo_conway(WithEqualityById, AlgebraicClosu
             sage: F = AlgebraicClosureFiniteField_pseudo_conway(GF(5), 'z')
             sage: F._get_polynomial(1)
             x + 3
-
         """
         return self._pseudo_conway_lattice.polynomial(n)
 
@@ -1137,7 +1099,6 @@ class AlgebraicClosureFiniteField_pseudo_conway(WithEqualityById, AlgebraicClosu
             sage: F = AlgebraicClosureFiniteField_pseudo_conway(GF(5), 'z')
             sage: F._get_im_gen(2, 4)
             z4^3 + z4^2 + z4 + 3
-
         """
         p = self.characteristic()
         if m == 1:
@@ -1177,7 +1138,6 @@ def AlgebraicClosureFiniteField(base_ring, name, category=None, implementation=N
 
     This is to ensure that the result of comparing two instances
     cannot change with time.
-
     """
     if category is None:
         from sage.categories.fields import Fields
