@@ -195,14 +195,12 @@ class NumberFieldHomset(RingHomset_generic):
             sage: x = polygen(ZZ, 'x')
             sage: K.<a> = NumberField(x^3 - 3*x + 1)
             sage: End(K).list()
-            [
-            Ring endomorphism of Number Field in a with defining polynomial x^3 - 3*x + 1
-              Defn: a |--> a,
-            Ring endomorphism of Number Field in a with defining polynomial x^3 - 3*x + 1
-              Defn: a |--> a^2 - 2,
-            Ring endomorphism of Number Field in a with defining polynomial x^3 - 3*x + 1
-              Defn: a |--> -a^2 - a + 2
-            ]
+            [Ring endomorphism of Number Field in a with defining polynomial x^3 - 3*x + 1
+               Defn: a |--> a,
+             Ring endomorphism of Number Field in a with defining polynomial x^3 - 3*x + 1
+               Defn: a |--> a^2 - 2,
+             Ring endomorphism of Number Field in a with defining polynomial x^3 - 3*x + 1
+               Defn: a |--> -a^2 - a + 2]
             sage: Hom(K, CyclotomicField(9))[0] # indirect doctest
             Ring morphism:
               From: Number Field in a with defining polynomial x^3 - 3*x + 1
@@ -214,20 +212,18 @@ class NumberFieldHomset(RingHomset_generic):
             sage: K.<a> = NumberField(x^3 - 2)
             sage: L.<b> = K.extension(x^2 + 3)
             sage: Hom(K, L).list()
-            [
-            Ring morphism:
-              From: Number Field in a with defining polynomial x^3 - 2
-              To:   Number Field in b with defining polynomial x^2 + 3 over its base field
-              Defn: a |--> a,
-            Ring morphism:
-              From: Number Field in a with defining polynomial x^3 - 2
-              To:   Number Field in b with defining polynomial x^2 + 3 over its base field
-              Defn: a |--> -1/2*a*b - 1/2*a,
-            Ring morphism:
-              From: Number Field in a with defining polynomial x^3 - 2
-              To:   Number Field in b with defining polynomial x^2 + 3 over its base field
-              Defn: a |--> 1/2*a*b - 1/2*a
-            ]
+            [Ring morphism:
+               From: Number Field in a with defining polynomial x^3 - 2
+               To:   Number Field in b with defining polynomial x^2 + 3 over its base field
+               Defn: a |--> a,
+             Ring morphism:
+               From: Number Field in a with defining polynomial x^3 - 2
+               To:   Number Field in b with defining polynomial x^2 + 3 over its base field
+               Defn: a |--> -1/2*a*b - 1/2*a,
+             Ring morphism:
+               From: Number Field in a with defining polynomial x^3 - 2
+               To:   Number Field in b with defining polynomial x^2 + 3 over its base field
+               Defn: a |--> 1/2*a*b - 1/2*a]
         """
         D = self.domain()
         C = self.codomain()
@@ -240,7 +236,7 @@ class NumberFieldHomset(RingHomset_generic):
 
     def __getitem__(self, n):
         r"""
-        Return the ``n``th element of ``self.list()``.
+        Return the `n`-th element of ``self.list()``.
 
         EXAMPLES::
 
@@ -479,36 +475,30 @@ class RelativeNumberFieldHomset(NumberFieldHomset):
             sage: x = polygen(ZZ, 'x')
             sage: K.<a, b> = NumberField([x^2 + x + 1, x^3 + 2])
             sage: End(K).list()
-            [
-            Relative number field endomorphism of
-             Number Field in a with defining polynomial x^2 + x + 1 over its base field
-              Defn: a |--> a
-                    b |--> b,
-            ...
-            Relative number field endomorphism of
-             Number Field in a with defining polynomial x^2 + x + 1 over its base field
-              Defn: a |--> a
-                    b |--> -b*a - b
-            ]
+            [Relative number field endomorphism of Number Field in a with defining polynomial x^2 + x + 1 over its base field
+               Defn: a |--> a
+                     b |--> b,
+             ...
+             Relative number field endomorphism of Number Field in a with defining polynomial x^2 + x + 1 over its base field
+               Defn: a |--> a
+                     b |--> -b*a - b]
 
         An example with an absolute codomain::
 
             sage: x = polygen(ZZ, 'x')
             sage: K.<a, b> = NumberField([x^2 - 3, x^2 + 2])
             sage: Hom(K, CyclotomicField(24, 'z')).list()
-            [
-            Relative number field morphism:
-              From: Number Field in a with defining polynomial x^2 - 3 over its base field
-              To:   Cyclotomic Field of order 24 and degree 8
-              Defn: a |--> z^6 - 2*z^2
-                    b |--> -z^5 - z^3 + z,
-            ...
-            Relative number field morphism:
-              From: Number Field in a with defining polynomial x^2 - 3 over its base field
-              To:   Cyclotomic Field of order 24 and degree 8
-              Defn: a |--> -z^6 + 2*z^2
-                    b |--> z^5 + z^3 - z
-            ]
+            [Relative number field morphism:
+               From: Number Field in a with defining polynomial x^2 - 3 over its base field
+               To:   Cyclotomic Field of order 24 and degree 8
+               Defn: a |--> z^6 - 2*z^2
+                     b |--> -z^5 - z^3 + z,
+             ...
+             Relative number field morphism:
+               From: Number Field in a with defining polynomial x^2 - 3 over its base field
+               To:   Cyclotomic Field of order 24 and degree 8
+               Defn: a |--> -z^6 + 2*z^2
+                     b |--> z^5 + z^3 - z]
         """
         D = self.domain()
         C = self.codomain()
