@@ -146,8 +146,7 @@ def build_and_print_matrices_deg_colored(v, strat):
     polys_in_mat.sort(key=pkey)
     global mat_counter
     mat_counter = mat_counter + 1
-    from PIL import Image
-    from PIL import ImageColor
+    from PIL import Image, ImageColor
 
     rows = len(polys_in_mat)
     cols = len(m2i)
