@@ -1,4 +1,3 @@
-# sage_setup: distribution = sagemath-objects
 """
 Dynamic classes
 
@@ -131,23 +130,23 @@ def dynamic_class(name, bases, cls=None, reduction=None, doccls=None,
     r"""
     INPUT:
 
-    - ``name`` -- a string
-    - ``bases`` -- a tuple of classes
+    - ``name`` -- string
+    - ``bases`` -- tuple of classes
     - ``cls`` -- a class or ``None``
-    - ``reduction`` -- a tuple or ``None``
+    - ``reduction`` -- tuple or ``None``
     - ``doccls`` -- a class or ``None``
-    - ``prepend_cls_bases`` -- a boolean (default: ``True``)
-    - ``cache`` -- a boolean or ``"ignore_reduction"`` (default: ``True``)
+    - ``prepend_cls_bases`` -- boolean (default: ``True``)
+    - ``cache`` -- boolean or ``'ignore_reduction'`` (default: ``True``)
 
     Constructs dynamically a new class ``C`` with name ``name``, and
     bases ``bases``. If ``cls`` is provided, then its methods will be
     inserted into ``C``, and its bases will be prepended to ``bases``
     (unless ``prepend_cls_bases`` is ``False``).
 
-    The module, documentation and source instrospection is taken from
+    The module, documentation and source introspection is taken from
     ``doccls``, or ``cls`` if ``doccls`` is ``None``, or ``bases[0]``
     if both are ``None`` (therefore ``bases`` should be non empty if
-    ``cls` is ``None``).
+    ``cls`` is ``None``).
 
     The constructed class can safely be pickled (assuming the
     arguments themselves can).
@@ -236,7 +235,7 @@ def dynamic_class(name, bases, cls=None, reduction=None, doccls=None,
     The following (meaningless) example illustrates how to customize
     the result of the reduction::
 
-        sage: BarFoo = dynamic_class("BarFoo", (Foo,), Bar, reduction = (str, (3,)))
+        sage: BarFoo = dynamic_class('BarFoo', (Foo,), Bar, reduction = (str, (3,)))
         sage: type(BarFoo).__reduce__(BarFoo)
         (<class 'str'>, (3,))
         sage: loads(dumps(BarFoo))
@@ -253,9 +252,9 @@ def dynamic_class(name, bases, cls=None, reduction=None, doccls=None,
 
     and the result depends on the reduction::
 
-        sage: dynamic_class("BarFoo", (Foo,), Bar, reduction = (str, (3,))) is BarFoo
+        sage: dynamic_class('BarFoo', (Foo,), Bar, reduction = (str, (3,))) is BarFoo
         True
-        sage: dynamic_class("BarFoo", (Foo,), Bar, reduction = (str, (2,))) is BarFoo
+        sage: dynamic_class('BarFoo', (Foo,), Bar, reduction = (str, (2,))) is BarFoo
         False
 
     With ``cache=False``, a new class is created each time::
@@ -272,14 +271,14 @@ def dynamic_class(name, bases, cls=None, reduction=None, doccls=None,
     With ``cache="ignore_reduction"``, the class does not depend on
     the reduction::
 
-        sage: BarFoo = dynamic_class("BarFoo", (Foo,), Bar, reduction = (str, (3,)), cache="ignore_reduction")
-        sage: dynamic_class("BarFoo", (Foo,), Bar, reduction = (str, (2,)), cache="ignore_reduction") is BarFoo
+        sage: BarFoo = dynamic_class('BarFoo', (Foo,), Bar, reduction = (str, (3,)), cache='ignore_reduction')
+        sage: dynamic_class('BarFoo', (Foo,), Bar, reduction = (str, (2,)), cache='ignore_reduction') is BarFoo
         True
 
     In particular, the reduction used is that provided upon creating the
     first class::
 
-        sage: dynamic_class("BarFoo", (Foo,), Bar, reduction = (str, (2,)), cache="ignore_reduction")._reduction
+        sage: dynamic_class('BarFoo', (Foo,), Bar, reduction = (str, (2,)), cache='ignore_reduction')._reduction
         (<class 'str'>, (3,))
 
     .. WARNING::
@@ -305,7 +304,7 @@ def dynamic_class(name, bases, cls=None, reduction=None, doccls=None,
         sage: pickle.loads(pickle.dumps(FooBar)) == FooBar
         True
 
-    We check that instrospection works reasonably::
+    We check that introspection works reasonably::
 
         sage: sage.misc.sageinspect.sage_getdoc(FooBar)
         'The Foo class\n'
@@ -363,7 +362,7 @@ def dynamic_class_internal(name, bases, cls=None, reduction=None, doccls=None, p
         sage: Foo3.__doc__ == sage.structure.dynamic_class.TestClass.__doc__
         True
 
-    We check that instrospection works reasonably::
+    We check that introspection works reasonably::
 
         sage: from sage.misc.sageinspect import sage_getfile, sage_getsourcelines
         sage: sage_getfile(Foo2)
