@@ -28,7 +28,7 @@ available_integrators['maxima'] = external.maxima_integrator
 available_integrators['sympy'] = external.sympy_integrator
 available_integrators['mathematica_free'] = external.mma_free_integrator
 available_integrators['fricas'] = external.fricas_integrator
-available_integrators['giac'] = external.giac_integrator
+available_integrators['giac'] = external.libgiac_integrator
 available_integrators['libgiac'] = external.libgiac_integrator
 
 ######################################################
@@ -59,9 +59,10 @@ class IndefiniteIntegral(BuiltinFunction):
 
         Check for :issue:`28913`::
 
+            sage: # needs sage.libs.giac
             sage: Ex = (1-2*x^(1/3))^(3/4)/x
             sage: integrate(Ex, x, algorithm='giac')  # long time
-            4*(-2*x^(1/3) + 1)^(3/4) + 6*arctan((-2*x^(1/3) + 1)^(1/4)) - 3*log((-2*x^(1/3) + 1)^(1/4) + 1) + 3*log(abs((-2*x^(1/3) + 1)^(1/4) - 1))
+            4*(-2*x^(1/3) + 1)^(3/4) + 6*arctan((-2*x^(1/3) + 1)^(1/4)) - 3*log(abs((-2*x^(1/3) + 1)^(1/4) + 1)) + 3*log(abs((-2*x^(1/3) + 1)^(1/4) - 1))
 
         Check for :issue:`29833`::
 
@@ -207,10 +208,13 @@ class DefiniteIntegral(BuiltinFunction):
 
         Check for :issue:`32354`::
 
+            sage: # needs sage.libs.giac
             sage: ex = 1/max_symbolic(x, 1)**2
             sage: integral(ex, x, 0, 2, algorithm='giac')
             3/2
-            sage: integral(1/max_symbolic(x, 1)**2, x, 0, oo, algorithm='giac')
+            sage: result = integral(1/max_symbolic(x, 1)**2, x, 0, oo, algorithm='giac')
+            ...
+            sage: result
             2
         """
         # The automatic evaluation routine will try these integrators
@@ -474,9 +478,9 @@ def integrate(expression, v=None, a=None, b=None, algorithm=None, hold=False):
 
       - ``'fricas'`` -- use FriCAS (the optional fricas spkg has to be installed)
 
-      - ``'giac'`` -- use Giac
+      - ``'giac'`` -- use libgiac
 
-      - ``'libgiac'`` -- use libgiac
+      - ``'libgiac'`` -- use libgiac (alias for ``'giac'``)
 
     To prevent automatic evaluation, use the ``hold`` argument.
 
@@ -610,10 +614,7 @@ def integrate(expression, v=None, a=None, b=None, algorithm=None, hold=False):
                  x y  + Sqrt[--] FresnelS[Sqrt[--] x]
                              2                 Pi
         sage: print(f.integral(x))
-        x*y^z + 1/16*sqrt(pi)*((I + 1)*sqrt(2)*erf((1/2*I + 1/2)*sqrt(2)*x)
-                                + (I - 1)*sqrt(2)*erf((1/2*I - 1/2)*sqrt(2)*x)
-                                - (I - 1)*sqrt(2)*erf(sqrt(-I)*x)
-                                + (I + 1)*sqrt(2)*erf((-1)^(1/4)*x))
+        x*y^z + 1/16*sqrt(pi)*((I + 1)*sqrt(2)*erf((1/2*I + 1/2)*sqrt(2)*x) - (I - 1)*sqrt(2)*erf(sqrt(-I)*x) - 2*sqrt(2)*imag_part(erf((-1)^(1/4)*x)) + 2*sqrt(2)*real_part(erf((-1)^(1/4)*x)))
 
     Alternatively, just use algorithm='mathematica_free' to integrate via Mathematica
     over the internet (does NOT require a Mathematica license!)::
@@ -680,12 +681,12 @@ def integrate(expression, v=None, a=None, b=None, algorithm=None, hold=False):
     The following definite integral is not found by maxima::
 
         sage: f(x) = (x^4 - 3*x^2 + 6) / (x^6 - 5*x^4 + 5*x^2 + 4)
-        sage: integrate(f(x), x, 1, 2, algorithm='maxima')
+        sage: integrate(f(x), x, 1, 2, algorithm='maxima')  # long time
         integrate((x^4 - 3*x^2 + 6)/(x^6 - 5*x^4 + 5*x^2 + 4), x, 1, 2)
 
     but is nevertheless computed::
 
-        sage: integrate(f(x), x, 1, 2)
+        sage: integrate(f(x), x, 1, 2)  # long time
         -1/2*pi + arctan(8) + arctan(5) + arctan(2) + arctan(1/2)
 
     Both fricas and sympy give the correct result::
@@ -695,9 +696,15 @@ def integrate(expression, v=None, a=None, b=None, algorithm=None, hold=False):
         sage: integrate(f(x), x, 1, 2, algorithm='sympy')                               # needs sympy
         -1/2*pi + arctan(8) + arctan(5) + arctan(2) + arctan(1/2)
 
-    Using Giac to integrate the absolute value of a trigonometric expression::
+    Using Giac to integrate the absolute value of a trigonometric
+    expression. If Giac is installed, this will be attempted
+    automatically in the event that Maxima is unable to integrate the
+    expression::
 
-        sage: integrate(abs(cos(x)), x, 0, 2*pi, algorithm='giac')
+        sage: # needs sage.libs.giac
+        sage: result = integrate(abs(cos(x)), x, 0, 2*pi, algorithm='giac')
+        ...
+        sage: result
         4
         sage: result = integrate(abs(cos(x)), x, 0, 2*pi)
         ...
@@ -989,46 +996,6 @@ def integrate(expression, v=None, a=None, b=None, algorithm=None, hold=False):
         sage: bool(actual == expected)
         True
 
-    ::
-
-        sage: # needs sage.libs.giac
-        sage: result = integrate(cos(x + abs(x)), x)
-        ...
-        sage: result
-        sin(x*sgn(x) + x)/(sgn(x) + 1)
-
-    ::
-
-        sage: # needs sage.libs.giac
-        sage: result = integrate(1/(1 + abs(x)), x)
-        ...
-        sage: result
-        log(abs(x*sgn(x) + 1))/sgn(x)
-
-    ::
-
-        sage: # needs sage.libs.giac
-        sage: result = integrate(1/sqrt(abs(x)), x)
-        ...
-        sage: result
-        2*sqrt(x*sgn(x))/sgn(x)
-
-    ::
-
-        sage: # needs sage.libs.giac
-        sage: result = integrate(1/(1 + abs(x)), x)
-        ...
-        sage: result
-        log(abs(x*sgn(x) + 1))/sgn(x)
-
-    ::
-
-        sage: # needs sage.libs.giac
-        sage: result = integrate(cos(x + abs(x)), x)
-        ...
-        sage: result
-        sin(x*sgn(x) + x)/(sgn(x) + 1)
-
     Some tests for :issue:`17468`::
 
         sage: integral(log(abs(2*sin(x))), x, 0, pi/3)
@@ -1066,7 +1033,7 @@ def integrate(expression, v=None, a=None, b=None, algorithm=None, hold=False):
         sage: assume(a > 0)
         sage: assume(a < 1)
         sage: integrate(x*log(1/(a*x+(1-x)^2)), x, 0, 1, algorithm='maxima')
-        1/4*a^2*log(a) + 1/2*sqrt(-a^2 + 4*a)*a*arctan(sqrt(-a^2 + 4*a)*(a - 2)/(a^2 - 4*a)) - 1/2*sqrt(-a^2 + 4*a)*a*arctan(sqrt(-a^2 + 4*a)/(a - 4)) - a*log(a) - sqrt(-a^2 + 4*a)*arctan(sqrt(-a^2 + 4*a)*(a - 2)/(a^2 - 4*a)) + sqrt(-a^2 + 4*a)*arctan(sqrt(-a^2 + 4*a)/(a - 4)) - 1/2*a + 3/2
+        1/4*a^2*log(a) - 1/2*sqrt(-a^2 + 4*a)*a*arctan(sqrt(-a^2 + 4*a)/(a - 4)) + 1/2*sqrt(-a^2 + 4*a)*a*arctan(sqrt(-a^2 + 4*a)*(a - 2)/((a - 4)*a)) - a*log(a) + sqrt(-a^2 + 4*a)*arctan(sqrt(-a^2 + 4*a)/(a - 4)) - sqrt(-a^2 + 4*a)*arctan(sqrt(-a^2 + 4*a)*(a - 2)/((a - 4)*a)) - 1/2*a + 3/2
 
     Check that :issue:`25905` is fixed::
 
